# Load the packages
library(rvest)
library(tidyverse)

#### list of 2018 Senators ####

# list of senators
senators <- c("Richard Shelby", "Doug Jones", "Lisa Murkowski", "Dan Sullivan", "Jeff Flake", 
              "Jon Kyl", "John Boozman", "Tom Cotton", "Dianne Feinstein", "Kamala Harris",
              "Michael Bennet", "Cory Gardner", "Richard Blumenthal", "Chris Murphy", 
              "Tom Carper", "Chris Coons", "Bill Nelson, Sr.", "Marco Rubio", "Johnny Isakson",
              "David Perdue", "Brian Schatz", "Mazie Hirono", "Mike Crapo", "James Risch",
              "Dick Durbin", "Tammy Duckworth", "Joe Donnelly, Sr.", "Todd Young", "Chuck Grassley",
              "Joni Ernst", "Pat Roberts", "Jerry Moran", "Mitch McConnell, Jr.", "Rand Paul", 
              "Bill Cassidy", "John Kennedy", "Susan Collins", "Angus King, Jr.", "Ben Cardin", 
              "Chris Van Hollen, Jr.", "Elizabeth Warren", "Ed Markey", "Debbie Stabenow", 
              "Gary Peters", "Amy Klobuchar", "Tina Smith", "Thad Cochran", "Cindy Hyde-Smith",
              "Roger Wicker", "Claire McCaskill", "Roy Blunt", "Jon Tester", "Steve Daines", 
              "Deb Fischer", "Ben Sasse", "Dean Heller", "Catherine Cortez Masto", 
              "Jeanne Shaheen", "Maggie Hassan", "Bob Menendez", "Cory Booker", "Tom Udall",
              "Martin Heinrich", "Chuck Schumer", "Kirsten Gillibrand", "Richard Burr", 
              "Thom Tillis", "Heidi Heitkamp", "John Hoeven", "Sherrod Brown", "Rob Portman",
              "Jim Inhofe", "James Lankford", "Ron Wyden", "Jeff Merkley", "Bob Casey, Jr.", 
              "Pat Toomey", "Jack Reed", "Sheldon Whitehouse", "Lindsey Graham", "Tim Scott", 
              "John Thune", "Mike Rounds", "Lamar Alexander", "Robert Corker", "John Cornyn", 
              "Ted Cruz", "Orrin Hatch", "Mike Lee", "Patrick Leahy", "Bernie Sanders", 
              "Mark Warner", "Tim Kaine", "Patty Murray", "Maria Cantwell", "Joe Manchin III", 
              "Shelley Capito", "Ron Johnson", "Tammy Baldwin", "Mike Enzi", "John Barrasso",
              "John McCain III")

# party affiliations
party <- c("Republican", "Democrat", "Republican", "Republican", "Republican",
           "Republican", "Republican", "Republican", "Democrat", "Democrat",
           "Democrat", "Republican", "Democrat", "Democrat", "Democrat", "Democrat", 
           "Democrat", "Republican", "Republican", "Republican", "Democrat", "Democrat", 
           "Republican", "Republican", "Democrat", "Democrat", "Democrat", "Republican", 
           "Republican", "Republican", "Republican", "Republican", "Republican", "Republican", 
           "Republican", "Republican", "Republican", "Independent", "Democrat", "Democrat",
           "Democrat", "Democrat", "Democrat", "Democrat", "Democrat", "Democrat", "Republican",
           "Republican", "Republican", "Democrat", "Republican", "Democrat", "Republican", 
           "Republican", "Republican", "Democrat", "Democrat", "Democrat", "Democrat", 
           "Democrat", "Democrat", "Democrat", "Democrat", "Republican", "Republican", "Democrat",
           "Republican", "Democrat", "Republican", "Republican", "Republican", "Democrat", 
           "Democrat", "Democrat", "Republican", "Democrat", "Democrat", "Republican", 
           "Republican", "Republican", "Republican", "Republican", "Republican", "Republican",
           "Republican", "Republican", "Democrat", "Independent", "Democrat", "Democrat", 
           "Democrat", "Democrat", "Democrat", "Republican", "Republican", "Democrat", 
           "Republican", "Democrat", "Republican", "Republican", "Republican", "Republican")

senators_df <- cbind(senators, party)
colnames(senators_df) <- c("Name","Party2")

senators_df[senators_df[,"Name"] == "Bernie Sanders", "Party2"] <- "Independent"
senators_df[senators_df[,"Name"] == "Chuck Schumer", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Dean Heller", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Jack Reed", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "James Lankford", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Jeff Merkley", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Jim Inhofe", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Kirsten Gillibrand", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Maria Cantwell", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Mike Lee", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Orrin Hatch", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Pat Toomey", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Patty Murray", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Richard Burr", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Ron Johnson", "Party2"] <- "Republican"
senators_df[senators_df[,"Name"] == "Sheldon Whitehouse", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Sherrod Brown", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Tammy Baldwin", "Party2"] <- "Democrat"
senators_df[senators_df[,"Name"] == "Ted Cruz", "Party2"] <- "Republican"

## table to hold final data output
final_table <- array(NA, c(12, 10, 2))


#### NRLC ####

# The URLs of the pages to scrape
nrlc_1 <- "https://justfacts.votesmart.org/interest-group/252/rating/10293$?p=1&of="
nrlc_2 <- "https://justfacts.votesmart.org/interest-group/252/rating/10293$?p=2&of="
nrlc_3 <- "https://justfacts.votesmart.org/interest-group/252/rating/10293$?p=3&of="
nrlc_4 <- "https://justfacts.votesmart.org/interest-group/252/rating/10293$?p=4&of="
nrlc_5 <- "https://justfacts.votesmart.org/interest-group/252/rating/10293$?p=5&of="
nrlc_6 <- "https://justfacts.votesmart.org/interest-group/252/rating/10293$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(nrlc_1)
page_2 <- read_html(nrlc_2)
page_3 <- read_html(nrlc_3)
page_4 <- read_html(nrlc_4)
page_5 <- read_html(nrlc_5)
page_6 <- read_html(nrlc_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_nrlc <- data[data$Name %in% senators, ]
print(data_nrlc, n=200)

# merge party id
data_nrlc <- merge(data_nrlc, senators_df, by="Name")

# categorical ratings
data_nrlc$rating_cat <- findInterval(as.numeric(substr(data_nrlc$Rating, 1, nchar(data_nrlc$Rating)-1)), c(0,20,40,60,80,101))
data_nrlc$rating_cat <- factor(data_nrlc$rating_cat, levels = 1:5)

# partisan distribution
final_table[1,1:5,1] <- table(data_nrlc$rating_cat[data_nrlc$Party2 == "Republican"]) / sum(table(data_nrlc$rating_cat[data_nrlc$Party2 == "Republican"]))
final_table[1,1:5,2] <- table(data_nrlc$rating_cat[data_nrlc$Party2 == "Democrat"]) / sum(table(data_nrlc$rating_cat[data_nrlc$Party2 == "Democrat"]))


#### CfG ####

# The URLs of the pages to scrape
cfg_1 <- "https://justfacts.votesmart.org/interest-group/1734/rating/11071$?p=1&of="
cfg_2 <- "https://justfacts.votesmart.org/interest-group/1734/rating/11071$?p=2&of="
cfg_3 <- "https://justfacts.votesmart.org/interest-group/1734/rating/11071$?p=3&of="
cfg_4 <- "https://justfacts.votesmart.org/interest-group/1734/rating/11071$?p=4&of="
cfg_5 <- "https://justfacts.votesmart.org/interest-group/1734/rating/11071$?p=5&of="
cfg_6 <- "https://justfacts.votesmart.org/interest-group/1734/rating/11071$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(cfg_1)
page_2 <- read_html(cfg_2)
page_3 <- read_html(cfg_3)
page_4 <- read_html(cfg_4)
page_5 <- read_html(cfg_5)
page_6 <- read_html(cfg_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_cfg <- data[data$Name %in% senators, ]
print(data_cfg, n=200)

# merge party id
data_cfg <- merge(data_cfg, senators_df, by="Name")

# categorical ratings
data_cfg$rating_cat <- findInterval(as.numeric(substr(data_cfg$Rating, 1, nchar(data_cfg$Rating)-1)), c(0,20,40,60,80,101))
data_cfg$rating_cat <- factor(data_cfg$rating_cat, levels = 1:5)

# partisan distribution
final_table[2,1:5,1] <- table(data_cfg$rating_cat[data_cfg$Party2 == "Republican"]) / sum(table(data_cfg$rating_cat[data_cfg$Party2 == "Republican"]))
final_table[2,1:5,2] <- table(data_cfg$rating_cat[data_cfg$Party2 == "Democrat"]) / sum(table(data_cfg$rating_cat[data_cfg$Party2 == "Democrat"]))


#### HRC ####

# The URLs of the pages to scrape
hrc_1 <- "https://justfacts.votesmart.org/interest-group/1256/rating/10918$?p=1&of="
hrc_2 <- "https://justfacts.votesmart.org/interest-group/1256/rating/10918$?p=2&of="
hrc_3 <- "https://justfacts.votesmart.org/interest-group/1256/rating/10918$?p=3&of="
hrc_4 <- "https://justfacts.votesmart.org/interest-group/1256/rating/10918$?p=4&of="
hrc_5 <- "https://justfacts.votesmart.org/interest-group/1256/rating/10918$?p=5&of="
hrc_6 <- "https://justfacts.votesmart.org/interest-group/1256/rating/10918$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(hrc_1)
page_2 <- read_html(hrc_2)
page_3 <- read_html(hrc_3)
page_4 <- read_html(hrc_4)
page_5 <- read_html(hrc_5)
page_6 <- read_html(hrc_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_hrc <- data[data$Name %in% senators, ]
print(data_hrc, n=200)

# merge party id
data_hrc <- merge(data_hrc, senators_df, by="Name")

# categorical ratings
data_hrc$rating_cat <- findInterval(as.numeric(substr(data_hrc$Rating, 1, nchar(data_hrc$Rating)-1)), c(0,20,40,60,80,101))
data_hrc$rating_cat <- factor(data_hrc$rating_cat, levels = 1:5)

# partisan distribution
final_table[3,1:5,1] <- table(data_hrc$rating_cat[data_hrc$Party2 == "Republican"]) / sum(table(data_hrc$rating_cat[data_hrc$Party2 == "Republican"]))
final_table[3,1:5,2] <- table(data_hrc$rating_cat[data_hrc$Party2 == "Democrat"]) / sum(table(data_hrc$rating_cat[data_hrc$Party2 == "Democrat"]))


#### NAACP ####

# The URLs of the pages to scrape
naacp_1 <- "https://justfacts.votesmart.org/interest-group/893/rating/11075$?p=1&of="
naacp_2 <- "https://justfacts.votesmart.org/interest-group/893/rating/11075$?p=2&of="
naacp_3 <- "https://justfacts.votesmart.org/interest-group/893/rating/11075$?p=3&of="
naacp_4 <- "https://justfacts.votesmart.org/interest-group/893/rating/11075$?p=4&of="
naacp_5 <- "https://justfacts.votesmart.org/interest-group/893/rating/11075$?p=5&of="
naacp_6 <- "https://justfacts.votesmart.org/interest-group/893/rating/11075$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(naacp_1)
page_2 <- read_html(naacp_2)
page_3 <- read_html(naacp_3)
page_4 <- read_html(naacp_4)
page_5 <- read_html(naacp_5)
page_6 <- read_html(naacp_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_naacp <- data[data$Name %in% senators, ]
print(data_naacp, n=200)

# merge party id
data_naacp <- merge(data_naacp, senators_df, by="Name")

# categorical ratings
data_naacp$rating_cat <- findInterval(as.numeric(substr(data_naacp$Rating, 1, nchar(data_naacp$Rating)-1)), c(0,20,40,60,80,101))
data_naacp$rating_cat <- factor(data_naacp$rating_cat, levels = 1:5)

# partisan distribution
final_table[4,1:5,1] <- table(data_naacp$rating_cat[data_naacp$Party2 == "Republican"]) / sum(table(data_naacp$rating_cat[data_naacp$Party2 == "Republican"]))
final_table[4,1:5,2] <- table(data_naacp$rating_cat[data_naacp$Party2 == "Democrat"]) / sum(table(data_naacp$rating_cat[data_naacp$Party2 == "Democrat"]))


#### NORML ####

# The URLs of the pages to scrape
norml_1 <- "https://justfacts.votesmart.org/interest-group/599/rating/9995$?p=1&of="
norml_2 <- "https://justfacts.votesmart.org/interest-group/599/rating/9995$?p=2&of="
norml_3 <- "https://justfacts.votesmart.org/interest-group/599/rating/9995$?p=3&of="
norml_4 <- "https://justfacts.votesmart.org/interest-group/599/rating/9995$?p=4&of="
norml_5 <- "https://justfacts.votesmart.org/interest-group/599/rating/9995$?p=5&of="
norml_6 <- "https://justfacts.votesmart.org/interest-group/599/rating/9995$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(norml_1)
page_2 <- read_html(norml_2)
page_3 <- read_html(norml_3)
page_4 <- read_html(norml_4)
page_5 <- read_html(norml_5)
page_6 <- read_html(norml_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_norml <- data[data$Name %in% senators, ]
print(data_norml, n=200)

# merge party id
data_norml <- merge(data_norml, senators_df, by="Name")

# categorical ratings
data_norml$rating_cat <- findInterval(as.numeric(substr(data_norml$Rating, 1, nchar(data_norml$Rating)-1)), c(0,20,40,60,80,101))
data_norml$rating_cat <- factor(data_norml$rating_cat, levels = 1:5)

# partisan distribution
final_table[5,1:5,1] <- table(data_norml$rating_cat[data_norml$Party2 == "Republican"]) / sum(table(data_norml$rating_cat[data_norml$Party2 == "Republican"]))
final_table[5,1:5,2] <- table(data_norml$rating_cat[data_norml$Party2 == "Democrat"]) / sum(table(data_norml$rating_cat[data_norml$Party2 == "Democrat"]))


#### AFA ####

# The URLs of the pages to scrape
afa_1 <- "https://justfacts.votesmart.org/interest-group/2622/rating/10307$?p=1&of="
afa_2 <- "https://justfacts.votesmart.org/interest-group/2622/rating/10307$?p=2&of="
afa_3 <- "https://justfacts.votesmart.org/interest-group/2622/rating/10307$?p=3&of="
afa_4 <- "https://justfacts.votesmart.org/interest-group/2622/rating/10307$?p=4&of="
afa_5 <- "https://justfacts.votesmart.org/interest-group/2622/rating/10307$?p=5&of="
afa_6 <- "https://justfacts.votesmart.org/interest-group/2622/rating/10307$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(afa_1)
page_2 <- read_html(afa_2)
page_3 <- read_html(afa_3)
page_4 <- read_html(afa_4)
page_5 <- read_html(afa_5)
page_6 <- read_html(afa_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_afa <- data[data$Name %in% senators, ]
print(data_afa, n=200)

# merge party id
data_afa <- merge(data_afa, senators_df, by="Name")

# categorical ratings
data_afa$rating_cat <- findInterval(as.numeric(substr(data_afa$Rating, 1, nchar(data_afa$Rating)-1)), c(0,20,40,60,80,101))
data_afa$rating_cat <- factor(data_afa$rating_cat, levels = 1:5)

# partisan distribution
final_table[6,1:5,1] <- table(data_afa$rating_cat[data_afa$Party2 == "Republican"]) / sum(table(data_afa$rating_cat[data_afa$Party2 == "Republican"]))
final_table[6,1:5,2] <- table(data_afa$rating_cat[data_afa$Party2 == "Democrat"]) / sum(table(data_afa$rating_cat[data_afa$Party2 == "Democrat"]))


#### LCV ####

# The URLs of the pages to scrape
lcv_1 <- "https://justfacts.votesmart.org/interest-group/1012/rating/10969$?p=1&of="
lcv_2 <- "https://justfacts.votesmart.org/interest-group/1012/rating/10969$?p=2&of="
lcv_3 <- "https://justfacts.votesmart.org/interest-group/1012/rating/10969$?p=3&of="
lcv_4 <- "https://justfacts.votesmart.org/interest-group/1012/rating/10969$?p=4&of="
lcv_5 <- "https://justfacts.votesmart.org/interest-group/1012/rating/10969$?p=5&of="
lcv_6 <- "https://justfacts.votesmart.org/interest-group/1012/rating/10969$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(lcv_1)
page_2 <- read_html(lcv_2)
page_3 <- read_html(lcv_3)
page_4 <- read_html(lcv_4)
page_5 <- read_html(lcv_5)
page_6 <- read_html(lcv_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_lcv <- data[data$Name %in% senators, ]
print(data_lcv, n=200)

# merge party id
data_lcv <- merge(data_lcv, senators_df, by="Name")

# categorical ratings
data_lcv$rating_cat <- findInterval(as.numeric(substr(data_lcv$Rating, 1, nchar(data_lcv$Rating)-1)), c(0,20,40,60,80,101))
data_lcv$rating_cat <- factor(data_lcv$rating_cat, levels = 1:5)

# partisan distribution
final_table[7,1:5,1] <- table(data_lcv$rating_cat[data_lcv$Party2 == "Republican"]) / sum(table(data_lcv$rating_cat[data_lcv$Party2 == "Republican"]))
final_table[7,1:5,2] <- table(data_lcv$rating_cat[data_lcv$Party2 == "Democrat"]) / sum(table(data_lcv$rating_cat[data_lcv$Party2 == "Democrat"]))


#### NRA (use 2016 and 2018) ####

## 2018 ##

# 100 total pages
urls <- c()
page <- list()
for (i in 1:100){
  
  urls[i] <- paste0("https://justfacts.votesmart.org/interest-group/1034/rating/12493$?p=", i, "&of=")
  page[[i]] <- read_html(urls[i])
  
  # Find the table on the page and extract the text from each cell
  table <- page[[i]] %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
}

# keep only Senators
data_nra_18 <- data[data$Name %in% senators, ]
print(data_nra_18, n=200)

## 2016 ##

# 136 total pages
urls <- c()
page <- list()
for (i in 1:100){
  
  urls[i] <- paste0("https://justfacts.votesmart.org/interest-group/1034/rating/10178$?p=", i, "&of=")
  page[[i]] <- read_html(urls[i])
  
  # Find the table on the page and extract the text from each cell
  table <- page[[i]] %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
}

# keep only Senators
data_nra_16 <- data[data$Name %in% senators, ]
print(data_nra_16, n=200)

## merge two years
data_nra <- rbind(data_nra_18, data_nra_16)
data_nra <- data_nra[grepl("U.S. Senate", data_nra$Office, fixed = TRUE), ]
print(data_nra, n=200)

## party distribution

# merge party id
data_nra <- merge(data_nra, senators_df, by="Name")

# categorical ratings
data_nra$rating_cat <- findInterval(as.numeric(substr(data_nra$Rating, 1, nchar(data_nra$Rating)-1)), c(0,20,40,60,80,101))
data_nra$rating_cat <- factor(data_nra$rating_cat, levels = 1:5)

# partisan distribution
final_table[8,1:5,1] <- table(data_nra$rating_cat[data_nra$Party2 == "Republican"]) / sum(table(data_nra$rating_cat[data_nra$Party2 == "Republican"]))
final_table[8,1:5,2] <- table(data_nra$rating_cat[data_nra$Party2 == "Democrat"]) / sum(table(data_nra$rating_cat[data_nra$Party2 == "Democrat"]))


#### NUSA ####

# The URLs of the pages to scrape
nusa_1 <- "https://justfacts.votesmart.org/interest-group/1985/rating/9705$?p=1&of="
nusa_2 <- "https://justfacts.votesmart.org/interest-group/1985/rating/9705$?p=2&of="
nusa_3 <- "https://justfacts.votesmart.org/interest-group/1985/rating/9705$?p=3&of="
nusa_4 <- "https://justfacts.votesmart.org/interest-group/1985/rating/9705$?p=4&of="
nusa_5 <- "https://justfacts.votesmart.org/interest-group/1985/rating/9705$?p=5&of="
nusa_6 <- "https://justfacts.votesmart.org/interest-group/1985/rating/9705$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(nusa_1)
page_2 <- read_html(nusa_2)
page_3 <- read_html(nusa_3)
page_4 <- read_html(nusa_4)
page_5 <- read_html(nusa_5)
page_6 <- read_html(nusa_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_nusa <- data[data$Name %in% senators, ]
print(data_nusa, n=200)

# merge party id
data_nusa <- merge(data_nusa, senators_df, by="Name")

# categorical ratings
data_nusa$rating_cat <- findInterval(as.numeric(substr(data_nusa$Rating, 1, nchar(data_nusa$Rating)-1)), c(0,20,40,60,80,101))
data_nusa$rating_cat <- factor(data_nusa$rating_cat, levels = 1:5)

# partisan distribution
final_table[9,1:5,1] <- table(data_nusa$rating_cat[data_nusa$Party2 == "Republican"]) / sum(table(data_nusa$rating_cat[data_nusa$Party2 == "Republican"]))
final_table[9,1:5,2] <- table(data_nusa$rating_cat[data_nusa$Party2 == "Democrat"]) / sum(table(data_nusa$rating_cat[data_nusa$Party2 == "Democrat"]))


#### AFL-CIO ####

# The URLs of the pages to scrape
aflcio_1 <- "https://justfacts.votesmart.org/interest-group/1161/rating/11758$?p=1&of="
aflcio_2 <- "https://justfacts.votesmart.org/interest-group/1161/rating/11758$?p=2&of="
aflcio_3 <- "https://justfacts.votesmart.org/interest-group/1161/rating/11758$?p=3&of="
aflcio_4 <- "https://justfacts.votesmart.org/interest-group/1161/rating/11758$?p=4&of="
aflcio_5 <- "https://justfacts.votesmart.org/interest-group/1161/rating/11758$?p=5&of="
aflcio_6 <- "https://justfacts.votesmart.org/interest-group/1161/rating/11758$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(aflcio_1)
page_2 <- read_html(aflcio_2)
page_3 <- read_html(aflcio_3)
page_4 <- read_html(aflcio_4)
page_5 <- read_html(aflcio_5)
page_6 <- read_html(aflcio_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_aflcio <- data[data$Name %in% senators, ]
print(data_aflcio, n=200)

# merge party id
data_aflcio <- merge(data_aflcio, senators_df, by="Name")

# categorical ratings
data_aflcio$rating_cat <- findInterval(as.numeric(substr(data_aflcio$Rating, 1, nchar(data_aflcio$Rating)-1)), c(0,20,40,60,80,101))
data_aflcio$rating_cat <- factor(data_aflcio$rating_cat, levels = 1:5)

# partisan distribution
final_table[10,1:5,1] <- table(data_aflcio$rating_cat[data_aflcio$Party2 == "Republican"]) / sum(table(data_aflcio$rating_cat[data_aflcio$Party2 == "Republican"]))
final_table[10,1:5,2] <- table(data_aflcio$rating_cat[data_aflcio$Party2 == "Democrat"]) / sum(table(data_aflcio$rating_cat[data_aflcio$Party2 == "Democrat"]))


#### Results ####

# The URLs of the pages to scrape
results_1 <- "https://justfacts.votesmart.org/interest-group/1744/rating/10358$?p=1&of="
results_2 <- "https://justfacts.votesmart.org/interest-group/1744/rating/10358$?p=2&of="
results_3 <- "https://justfacts.votesmart.org/interest-group/1744/rating/10358$?p=3&of="
results_4 <- "https://justfacts.votesmart.org/interest-group/1744/rating/10358$?p=4&of="
results_5 <- "https://justfacts.votesmart.org/interest-group/1744/rating/10358$?p=5&of="
results_6 <- "https://justfacts.votesmart.org/interest-group/1744/rating/10358$?p=6&of="

# Read the HTML content from the page
page_1 <- read_html(results_1)
page_2 <- read_html(results_2)
page_3 <- read_html(results_3)
page_4 <- read_html(results_4)
page_5 <- read_html(results_5)
page_6 <- read_html(results_6)

# build table
for (i in 1:6){
  
  # Find the table on the page and extract the text from each cell
  table <- eval(parse(text=paste0("page_", i))) %>%
    html_nodes("table") %>%
    html_table(fill = TRUE)
  
  # keep only 1st table
  if (i==1){
    data <- table[[1]]
  }else{
    data <- rbind(data, table[[1]])
  }
  
}

# keep only Senators
data_results <- data[data$Name %in% senators, ]
print(data_results, n=200)

# merge party id
data_results <- merge(data_results, senators_df, by="Name")

# categorical ratings
data_results$rating_cat <- findInterval(as.numeric(substr(data_results$Rating, 1, nchar(data_results$Rating)-1)), c(0,20,40,60,80,101))
data_results$rating_cat <- factor(data_results$rating_cat, levels = 1:5)

# partisan distribution
final_table[11,1:5,1] <- table(data_results$rating_cat[data_results$Party2 == "Republican"]) / sum(table(data_results$rating_cat[data_results$Party2 == "Republican"]))
final_table[11,1:5,2] <- table(data_results$rating_cat[data_results$Party2 == "Democrat"]) / sum(table(data_results$rating_cat[data_results$Party2 == "Democrat"]))


#### NOMINATE ####

# bring in NOMINATE scores for 2017-19
nom_18 <- read.csv("Data/NOMINATE_2017-19.csv", stringsAsFactors = F)
nom_18

# keep only last name
nom_18$lastname <- NA
for (i in 1:nrow(nom_18)){nom_18$lastname[i] <- strsplit(nom_18$bioname[i], " +")[[1]][1]}

# rank order by 1st dim and remove commas
nom_18_rank <- toupper(gsub(",", "", nom_18[order(nom_18$nominate_dim1), c("lastname","nominate_dim1"), ][,1]))

# find Senators' rankings
nom_rank <- array(NA, c(length(senators), 3))
for (i in 1:length(senators)){
  nom_rank[i,1] <- senators[i]
  nom_rank[i,2] <- strsplit(gsub(",", "", senators[i]), " +")[[1]][2]
}
nom_rank[,3] <- unlist(sapply(nom_rank[,2], function(x) which(sapply(nom_18_rank, 
                                                                     function(y) identical(toupper(x), y))
                                                              )
                              )
                       )
nom_rank

# merge party id
colnames(nom_rank) <- c("Name","Last","Rating")
nom_rank <- merge(nom_rank, senators_df, by="Name")

# categorical ratings
nom_rank$Rating_100 <- (as.numeric(nom_rank[,"Rating"]) / max(as.numeric(nom_rank[,"Rating"]))) * 100
nom_rank$rating_cat <- findInterval(nom_rank$Rating_100, c(0,10,20,30,40,50,60,70,80,90,101))
nom_rank$rating_cat <- factor(nom_rank$rating_cat, levels = 1:10)

# partisan distribution
final_table[12,,1] <- table(nom_rank$rating_cat[nom_rank$Party2 == "Republican"]) / sum(table(nom_rank$rating_cat[nom_rank$Party2 == "Republican"]))
final_table[12,,2] <- table(nom_rank$rating_cat[nom_rank$Party2 == "Democrat"]) / sum(table(nom_rank$rating_cat[nom_rank$Party2 == "Democrat"]))



#### Export final table ####

# label dimensions
dimnames(final_table) <- list(c("nrlc","cfg","hrc","naacp","normal","afa","lcv","nra","nusa","aflcio","results","nominate"),
                              c("1","2","3","4","5","6","7","8","9","10"),
                              c("Republicans","Democrats"))

# save to RDS file
saveRDS(final_table, "Data/Distribution of Ratings by Party.RDS")


