##### Survey Data Cleaning and Coding #####

# clear environment
rm(list=ls())


### data cleaning wave 1

# load survey and mturk data
wave1 <- read.csv("Data/Campaign_Learning_Wave1.csv", stringsAsFactors = F)
mturk1 <- read.csv("Data/mturk_info_wave1.csv", stringsAsFactors = F)

# subset based on presence in mturk sheet
wave1 <- subset(wave1, as.character(wave1$MID) %in% as.character(mturk1$WorkerId))

# subset based on missingness / duplication
length(unique(as.character(wave1$MID)))
extra <- which(duplicated(as.character(wave1$MID)))
length(unique(as.character(wave1$MID[extra]))) # 107 people with duplication to some degree
wave1$na_count <- apply(wave1, 1, function(x) sum(is.na(x))) # calculate total NAs
length(which(wave1$na_count < 400)) # there are about 932 usable cases
wave1 <- subset(wave1, wave1$na_count < 400)
extra <- which(duplicated(as.character(wave1$MID)))
length(extra) # after the subset only one duplicate is left

# subset based on state match
head(wave1$state) # self report
head(wave1$state_code) # scraped geo ip
head(wave1$state_name) # scraped geo ip
state_info <- read.csv("Data/senate_race_info18.csv", stringsAsFactors = F)[,-9] # remove notes column
state_info$state_code
state_info$state
wave1$state_self <- c()
for(i in 1:length(wave1$state)) {
  # catch situation where self_reported state is ineligible
  if(length(which(state_info$state_code == wave1$state[i])) == 1)
    wave1$state_self[i] <- as.character(state_info$state[which(state_info$state_code == wave1$state[i])])
  else
    wave1$state_self[i] <- ""
}

# compare state_self with state_name
length(which(wave1$state_name != wave1$state_self)) # 135
mismatch <- which(wave1$state_name != wave1$state_self)
wave1$state_name[mismatch]
wave1$state_self[mismatch]
wave1 <- subset(wave1, wave1$state_name == wave1$state_self)
extra <- which(duplicated(as.character(wave1$MID)))
length(extra) # remaining duplicate is gone


### data cleaning wave 2

# load data
wave2 <- read.csv("Data/Campaign_Learning_Wave2.csv", stringsAsFactors = F)
mturk_eligible <- read.csv("Data/mturk_wave2_eligible.csv")
mturk2 <- read.csv("Data/mturk_info_wave2.csv")

# subset by mturk id file to only get those who completed
length(which(duplicated(mturk2$WorkerId)))
length(which(mturk2$WorkerId %in% mturk_eligible$WorkerId))
mturk2 <- subset(mturk2, mturk2$WorkerId %in% mturk_eligible$WorkerId)

# subset based on presence in both mTurk sheets
wave2 <- subset(wave2, as.character(wave2$MID) %in% as.character(mturk2$WorkerId))

# subset based on missingness / duplication
length(unique(as.character(wave2$MID)))
extra <- which(duplicated(as.character(wave2$MID)))
length(unique(as.character(wave2$MID[extra]))) # 46 people with duplication to some degree

wave2$na_count <- apply(wave2, 1, function(x) sum(is.na(x)))
length(which(wave2$na_count >= 400)) # 608 usable cases

wave2 <- subset(wave2, wave2$na_count < 400)
extra <- which(duplicated(as.character(wave2$MID)))
length(extra) # after the subset 22 duplicates remain

drop <- which(wave2$MID %in% wave2$MID[extra])
wave2 <- wave2[-drop, ]
nrow(wave2) # 564


### variable coding


# time to complete survey
wave1$time_complete <- as.numeric(difftime(wave1$V9, wave1$V8))
summary(wave1$time_complete)


## R's background and politics

# age
wave1$age <- 2018 - wave1$age
wave1$age01 <- (wave1$age - min(wave1$age, na.rm = T)) / (max(wave1$age, na.rm = T) - min(wave1$age, na.rm = T))
summary(wave1$age01)
cps_age <- findInterval(wave1$age, c(0,25,35,45,55,65,120))
table(cps_age) / sum(table(cps_age))

# gender
length(which(wave1$gender == 3)) # how many select other
wave1$male <- ifelse(wave1$gender == 1, 1, 0)
table(wave1$male)
table(wave1$gender) / (sum(table(wave1$gender)))

# race (black, hisp)
wave1$black <- ifelse(is.na(wave1$race_2) | wave1$race_2 == 0, 0, 1)
wave1$hisp <- ifelse(is.na(wave1$race_3) | wave1$race_3 == 0, 0, 1)
table(wave1$black) / sum(table(wave1$black)) # Black
table(wave1$hisp) / sum(table(wave1$hisp)) # Hispanic

white_only <- table(!is.na(wave1$race_1) & is.na(wave1$race_2) & is.na(wave1$race_4)
      & is.na(wave1$race_5) & is.na(wave1$race_6) & is.na(wave1$race_7)
      & is.na(wave1$race_8))
white_only / sum(white_only)

black_only <- table(is.na(wave1$race_1) & !is.na(wave1$race_2) & is.na(wave1$race_4)
               & is.na(wave1$race_5) & is.na(wave1$race_6) & is.na(wave1$race_7)
               & is.na(wave1$race_8))
black_only / sum(black_only)

asian_only <- table(is.na(wave1$race_1) & is.na(wave1$race_2) & !is.na(wave1$race_4)
               & is.na(wave1$race_5) & is.na(wave1$race_6) & is.na(wave1$race_7)
               & is.na(wave1$race_8))
asian_only / sum(asian_only)

hisp_only<- table(is.na(wave1$race_1) & is.na(wave1$race_2) & is.na(wave1$race_4)
                  & is.na(wave1$race_5) & is.na(wave1$race_6) & is.na(wave1$race_7)
                  & is.na(wave1$race_8) & !is.na(wave1$race_3))
hisp_only / sum(hisp_only)

# education
wave1$educ01 <- (wave1$educ - 1) / 5
table(wave1$educ01)

# income
wave1$income01 <- (wave1$income - 1) / 12
table(wave1$income01)
summary(wave1$income)

# unemployed
wave1$unemp <- ifelse(wave1$employ == 3, 1, 0)
table(wave1$unemp)

# state (self-report), note that these numbers don't perfectly correspond with state order (includes DC & PR)
table(wave1$state)

# union
table(wave1$union)

# religious id and religiosity
table(wave1$relid) # id
wave1$relimp <- 6 - wave1$relimp # importance
wave1$relimp01 <- (wave1$relimp - 1) / 4
table(wave1$relimp01)

# partisanship
wave1$pid <- rowSums(cbind(wave1$demstr,wave1$repstr,wave1$lean), na.rm = T)
wave1$pid01 <- (wave1$pid - 1) / 6
table(wave1$pid01)

# % Lib, Con, Mod
sum(table(wave1$ideo[wave1$ideo %in% 1:3])) / sum(table(wave1$ideo)) # Libs
sum(table(wave1$ideo[wave1$ideo %in% 4])) / sum(table(wave1$ideo)) # Mods
sum(table(wave1$ideo[wave1$ideo %in% 5:7])) / sum(table(wave1$ideo)) # Cons

# ideo in ANES 2020
anes <- read.csv("Data/anes_timeseries_2020_csv_20220210.csv")
ideotab <- dplyr::count(anes, V201200, wt = V200010a)
ideoprop <- ideotab[ideotab$V201200 %in% 1:7, 2] / sum(ideotab[ideotab$V201200 %in% 1:7, 2])
sum(ideoprop[1:3]) / sum(ideoprop) #libs
sum(ideoprop[4]) / sum(ideoprop) #mods
sum(ideoprop[5:7]) / sum(ideoprop) #cons

# % Dem, Rep, Ind
table(wave1$pidcat) / sum(table(wave1$pidcat))

# pid in ANES 2020
pidtab <- dplyr::count(anes, V201228, wt = V200010a)
pidtab[pidtab$V201228 %in% 1:3, 2] / sum(pidtab[pidtab$V201228 %in% 1:3, 2])

# partisan identity strength
wave1$pid_str <- rowMeans(wave1[,c("dimp","rimp","ddesc","rdesc","dwe","rwe","dthink","rthink")], na.rm = T)
wave1$pid_str01 <- (wave1$pid_str - 1) / 4
summary(wave1$pid_str01)
hist(wave1$pid_str01)

wave2$pid_str <- rowMeans(wave2[,c("dimp","rimp","ddesc","rdesc","dwe","rwe","dthink","rthink")], na.rm = T)
wave2$pid_str01 <- (wave2$pid_str - 1) / 4
summary(wave2$pid_str01)
hist(wave2$pid_str01)

# issue importance to R
sort(table(wave1$most_imp), decreasing=TRUE)

wave1$imp_abort01 <- (wave1$issimp1_1 - 1) / 4 # abortion
wave1$imp_tax01 <- (wave1$issimp1_3 - 1) / 4 # taxes
wave1$imp_sex01 <- (wave1$issimp1_4 - 1) / 4 # gender & sexuality
wave1$imp_enviro01 <- (wave1$issimp1_7 - 1) / 4 # environment
wave1$imp_race01 <- (wave1$issimp2_1 - 1) / 4 # race
wave1$imp_relig01 <- (wave1$issimp2_2 - 1) / 4 # religion
wave1$imp_labor01 <- (wave1$issimp2_4 - 1) / 4 # labor
wave1$imp_drugs01 <- (wave1$issimp2_6 - 1) / 4 # drugs
wave1$imp_guns01 <- (wave1$issimp3_2 - 1) / 4 # guns
wave1$imp_immig01 <- (wave1$issimp3_3 - 1) / 4 # immigration
wave1$imp_welfare01 <- (wave1$issimp3_4 - 1) / 4 # welfare

wave2$imp_abort01 <- (wave2$issimp1_1 - 1) / 4 # abortion
wave2$imp_tax01 <- (wave2$issimp1_3 - 1) / 4 # taxes
wave2$imp_sex01 <- (wave2$issimp1_4 - 1) / 4 # gender & sexuality
wave2$imp_enviro01 <- (wave2$issimp1_7 - 1) / 4 # environment
wave2$imp_race01 <- (wave2$issimp2_1 - 1) / 4 # race
wave2$imp_relig01 <- (wave2$issimp2_2 - 1) / 4 # religion
wave2$imp_labor01 <- (wave2$issimp2_4 - 1) / 4 # labor
wave2$imp_drugs01 <- (wave2$issimp2_6 - 1) / 4 # drugs
wave2$imp_guns01 <- (wave2$issimp3_2 - 1) / 4 # guns
wave2$imp_immig01 <- (wave2$issimp3_3 - 1) / 4 # immigration
wave2$imp_welfare01 <- (wave2$issimp3_4 - 1) / 4 # welfare

# R's issue position
wave1$iss_nrlc01 <- wave1$issues1_1 / 100 # nrlc
wave1$iss_cfg01 <- wave1$issues1_3 / 100 # cfg
wave1$iss_hrc01 <- wave1$issues1_11 / 100 # hrc
wave1$iss_naacp01 <- wave1$issues1_12 / 100 # naacp
wave1$iss_afa01 <- wave1$issues2_2 / 100 # afa
wave1$iss_lcv01 <- wave1$issues2_3 / 100 # lcv
wave1$iss_aflcio01 <- wave1$issues2_8 / 100 # aflcio
wave1$iss_norml01 <- wave1$issues3_1 / 100 # norml
wave1$iss_nra01 <- wave1$issues3_2 / 100 # nra
wave1$iss_nusa01 <- wave1$issues3_3 / 100 # nusa
wave1$iss_results01 <- wave1$issues3_5 / 100 # results
wave1$iss_ideo01 <- wave1$ideo_senate_1 / 100 # NOMINATE

wave2$iss_nrlc01 <- wave2$issues1_1 / 100 # nrlc
wave2$iss_cfg01 <- wave2$issues1_3 / 100 # cfg
wave2$iss_hrc01 <- wave2$issues1_11 / 100 # hrc
wave2$iss_naacp01 <- wave2$issues1_12 / 100 # naacp
wave2$iss_afa01 <- wave2$issues2_2 / 100 # afa
wave2$iss_lcv01 <- wave2$issues2_3 / 100 # lcv
wave2$iss_aflcio01 <- wave2$issues2_8 / 100 # aflcio
wave2$iss_norml01 <- wave2$issues3_1 / 100 # norml
wave2$iss_nra01 <- wave2$issues3_2 / 100 # nra
wave2$iss_nusa01 <- wave2$issues3_3 / 100 # nusa
wave2$iss_results01 <- wave2$issues3_5 / 100 # results
wave2$iss_ideo01 <- wave2$ideo_senate_1 / 100 # NOMINATE

# attention to national politics
wave1$attend01 <- (wave1$attend - 1) / 4
table(wave1$attend01)

# consume news about politics
wave1$news01 <- wave1$news / 7
table(wave1$news01)

# how closely follows Senate election in home state
wave1$follow01 <- (wave1$follow - 1) / 4
table(wave1$follow01)

# political knowledge
wave1$kn1 <- ifelse(wave1$know1 == 4, 1, 0)
wave1$kn2 <- ifelse(wave1$know2 == 3, 1, 0)
wave1$kn3 <- ifelse(wave1$know3 == 3, 1, 0)
wave1$know01 <- rowSums(wave1[,c("kn1","kn2","kn3")], na.rm = T) / 3
table(wave1$know01)

# political engagement
wave1$engage01 <- rowMeans(wave1[,c("attend01","news01","follow01","know01")])
summary(wave1$engage01)
hist(wave1$engage01)
cor(wave1[,c("attend01","news01","follow01","know01")], use = "pairwise.complete")
pca <- prcomp(wave1[,c("attend01","news01","follow01","know01")])
print(pca)
plot(pca) # scree plot

# merge controls with wave 2
wave2 <- merge(wave2, wave1[,c("age01","male","black","hisp","educ01","income01",
                               "unemp","union","engage01","MID")], by="MID", all.y = F)

# export waves
write.csv(wave1, "Data/Wave 1 Coded.csv", row.names = F)
write.csv(wave2, "Data/Wave 2 Coded.csv", row.names = F)


##### Coding Beliefs and Accuracy #####

# clear environment
rm(list=ls())

# load coded waves 1 and 2
wave1 <- read.csv("Data/Wave 1 Coded.csv", stringsAsFactors = F)
wave2 <- read.csv("Data/Wave 2 Coded.csv", stringsAsFactors = F)

# load race info
state_info <- read.csv("Data/senate_race_info18.csv", stringsAsFactors = F)[,-9] # remove notes column

# vector of Senate candidate names
candidates <- c(state_info$dem_cand, state_info$rep_cand)

# vector of winning candidates
candidates_win <- c()
for (i in 1:nrow(state_info)){
  if (state_info$winner[i] == "dem"){
    candidates_win[i] <- state_info$dem_cand[i]
  }else if (state_info$winner[i] == "rep"){
    candidates_win[i] <- state_info$rep_cand[i]
  }else{
    candidates_win[i] <- "Angus King"
  }
}

# load project vote smart data
vote_smart <- read.csv("Data/Vote Smart Ratings.csv", stringsAsFactors = F)
vote_smart_all <- read.csv("Data/Vote Smart Ratings_All.csv", stringsAsFactors = F)
cand_data <- read.csv("Data/Candidates.csv", stringsAsFactors = F)
summary(vote_smart)
colnames(cand_data) <- c("candidate_id","ballot_name","state","office_party")

# verify all winning candidates are present in vote smart data
cbind(candidates_win,cand_data$ballot_name)

# cbind same-state/same-party pairs to relevant candidates
cand_data$samestate_id <- NA
cand_data$samestate_id[cand_data$candidate_id == 53273] <- 120012
cand_data$samestate_id[cand_data$candidate_id == 17189] <- 1568
cand_data$samestate_id[cand_data$candidate_id == 1677] <- 17852
cand_data$samestate_id[cand_data$candidate_id == 141272] <- 26900
cand_data$samestate_id[cand_data$candidate_id == 26888] <- 6098
cand_data$samestate_id[cand_data$candidate_id == 515] <- 8749
cand_data$samestate_id[cand_data$candidate_id == 21942] <- 66395
cand_data$samestate_id[cand_data$candidate_id == 65092] <- 152968
cand_data$samestate_id[cand_data$candidate_id == 21926] <- 20784
cand_data$samestate_id[cand_data$candidate_id == 41963] <- 150182
cand_data$samestate_id[cand_data$candidate_id == 26961] <- 76151
cand_data$samestate_id[cand_data$candidate_id == 74517] <- 22658
cand_data$samestate_id[cand_data$candidate_id == 65147] <- 26976
cand_data$samestate_id[cand_data$candidate_id == 25186] <- 15691
cand_data$samestate_id[cand_data$candidate_id == 135705] <- 15375
cand_data$samestate_id[cand_data$candidate_id == 124204] <- 1601
cand_data$samestate_id[cand_data$candidate_id == 148564] <- 120345
cand_data$samestate_id[cand_data$candidate_id == 169716] <- 418
cand_data$samestate_id[cand_data$candidate_id == 169471] <- 69579
cand_data$samestate_id[cand_data$candidate_id == 444] <- 41788
cand_data$samestate_id[cand_data$candidate_id == 50772] <- 535
cand_data$samestate_id[cand_data$candidate_id == 27122] <- 53358
cand_data$samestate_id[cand_data$candidate_id == 52662] <- 558

# assign winning candidate ID to panel respondents based on state residence
wave1$win_cand_id <- wave2$win_cand_id <- NA
for (i in 1:nrow(wave1)){
  wave1$win_cand_id[i] <- cand_data$candidate_id[cand_data$state == wave1$state_code[i]]
}
for (i in 1:nrow(wave2)){
  wave2$win_cand_id[i] <- cand_data$candidate_id[cand_data$state == wave2$state_code[i]]
}
unique(wave1$win_cand_id) # number of winning candidates available in survey data for analysis
unique(wave2$win_cand_id)

# determine winning candidate party for each respondent
wave1$win_cand_party <- wave1$win_cand_party <- NA
for (i in 1:nrow(wave1)){
  wave1$win_cand_party[i] <- cand_data$office_party[cand_data$candidate_id == wave1$win_cand_id[i]]
}
for (i in 1:nrow(wave2)){
  wave2$win_cand_party[i] <- cand_data$office_party[cand_data$candidate_id == wave2$win_cand_id[i]]
}


## perceived candidate ideology and issue positions

# function to extract respondent beliefs
getVectors <- function(...) {
  # ... = list of possible response options
  
  input_list <- list(...)
  ret <- matrix(nrow = length(input_list[[1]]), ncol = length(input_list))
  
  for(i in 1:length(input_list)) {
    ret[ ,i] <- input_list[[i]]
  }
  
  return(ret)
  
}

# function to calculate modified brier scores for ordered outcomes w/5 categories
brier <- function(resp,cand){
  
  if (length(cand) > 0){
    # determine correct answer
    correct <- rep(0,5)
    correct[findInterval(cand, c(0,20,40,60,80,101))] <- 1
    
    # calculate brier score
    scores <- c()
    for (i in 1:4){
     scores[i] <- (sum(resp[1:i])/100 - sum(correct[1:i]))^2 + (sum(resp[(i+1):5])/100 - sum(correct[(i+1):5]))^2 
    }
    brier <- mean(scores)
  }else{brier <- NA}

  return(brier)
}

# function to calculate modified brier scores for ordered outcomes w/10 categories
brier10 <- function(resp,cand){
  
  if (length(cand) > 0){
    # determine correct answer
    correct <- rep(0,10)
    correct[findInterval(cand, c(0,10,20,30,40,50,60,70,80,90,101))] <- 1
    
    # calculate brier score
    scores <- c()
    for (i in 1:9){
      scores[i] <- (sum(resp[1:i])/100 - sum(correct[1:i]))^2 + (sum(resp[(i+1):5])/100 - sum(correct[(i+1):5]))^2 
    }
    brier <- mean(scores)
  }else{brier <- NA}
  
  return(brier)
}

# bring in party baselines for interest group ratings
party_base <- readRDS("Data/Distribution of Ratings by Party.RDS")
party_base


### Score ratings ###

# party base for nominate (reverse so lib is higher)
nom_rep_base <- c()
nom_dem_base <- c()
for (i in 1:10){
  nom_rep_base[i] <- party_base["nominate", 10 - (i-1), "Republicans"] * 100
  nom_dem_base[10 - (i-1)] <- party_base["nominate", i, "Democrats"] * 100
}


# NOMINATE scores (102 total Senators during this period, adjust to range from 1-100)
# place same-state/same-party Senator in adjacent column
nominate <- matrix(c("Kyrsten Sinema", 46, NA,
                   "Dianne Feinstein", 34, 2,
                   "Chris Murphy", 33, 12,
                   "Rick Scott", 94, 87,
                   "Mazie K. Hirono", 6, 10,
                   "Mike Braun", 99, 77,
                   NA, NA, NA,
                   "Ben Cardin", 28, 15,
                   "Elizabeth A. Warren", 1, 5,
                   "Debbie Stabenow", 24, 35,
                   "Amy Klobuchar", 32, 14,
                   "Roger F. Wicker", 58, 61,
                   "Josh Hawley", 97, 69,
                   "Jon Tester", 41, NA,
                   "Deb Fischer", 76, 98,
                   "Jacky Rosen", 31, 16,
                   "Robert Menendez", 18, 3,
                   "Martin T. Heinrich", 27, 9,
                   "Kirsten E. Gillibrand", 8, 20,
                   "Kevin Cramer", 60, 56,
                   "Sherrod Brown", 13, NA,
                   "Robert P. Casey Jr.", 29, NA,
                   "Marsha Blackburn", 93, 53,
                   "Ted Cruz", 100, 78,
                   "Mitt Romney", 52, 102,
                   "Bernie Sanders", 4, NA,
                   "Timothy M. Kaine", 36, 42,
                   "Maria Cantwell", 30, 22,
                   "Joseph Manchin III", 48, NA,
                   "Tammy Baldwin", 7, NA,
                   "John Barrasso", 81, 82), 31, 3, byrow = T)
colnames(nominate) <- c("ballot_name","nominate","samestate")
nominate <- merge(nominate, cand_data[,c("candidate_id","ballot_name")], by="ballot_name")
nominate$nominate <- as.numeric(as.character(nominate$nominate))
nominate$samestate <- as.numeric(as.character(nominate$samestate))
nominate$nominate <- round(nominate$nominate/102*100)
nominate$samestate <- round(nominate$samestate/102*100)
nominate$nominate <- 101 - nominate$nominate
nominate$samestate <- 101 - nominate$samestate

dem_ideo_1 <- getVectors(wave1$Ideo_dem_1, wave1$Ideo_dem_2, wave1$Ideo_dem_3,
                         wave1$Ideo_dem_4, wave1$Ideo_dem_5, wave1$Ideo_dem_6, wave1$Ideo_dem_7,
                         wave1$Ideo_dem_8, wave1$Ideo_dem_9, wave1$Ideo_dem_11)

dem_ideo_2 <- getVectors(wave2$Ideo_dem_1, wave2$Ideo_dem_2, wave2$Ideo_dem_3,
                         wave2$Ideo_dem_4, wave2$Ideo_dem_5, wave2$Ideo_dem_6, wave2$Ideo_dem_7,
                         wave2$Ideo_dem_8, wave2$Ideo_dem_9, wave2$Ideo_dem_11)

rep_ideo_1 <- getVectors(wave1$Ideo_rep_1, wave1$Ideo_rep_2, wave1$Ideo_rep_3,
                         wave1$Ideo_rep_4, wave1$Ideo_rep_5, wave1$Ideo_rep_6, wave1$Ideo_rep_7,
                         wave1$Ideo_rep_8, wave1$Ideo_rep_9, wave1$Ideo_rep_10)

rep_ideo_2 <- getVectors(wave2$Ideo_rep_1, wave2$Ideo_rep_2, wave2$Ideo_rep_3,
                         wave2$Ideo_rep_4, wave2$Ideo_rep_5, wave2$Ideo_rep_6, wave2$Ideo_rep_7,
                         wave2$Ideo_rep_8, wave2$Ideo_rep_9, wave2$Ideo_rep_10)

wave1$brier_ideo <- wave2$brier_ideo <- NA
wave1$brier_ideo_base <- wave2$brier_ideo_base <- NA
wave1$brier_ideo_party <- wave2$brier_ideo_party <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_ideo[i] <- brier10(dem_ideo_1[i,],
                                 nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])]) 
    wave1$brier_ideo_base[i] <- brier10(rep(10, 10),
                                   nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])])
    wave1$brier_ideo_mid[i] <- brier10(c(rep(0, 5),rep(20,5)),
                                        nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])])
    wave1$brier_ideo_party[i] <- brier10(nom_dem_base,
                                      nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_ideo[i] <- brier10(rep_ideo_1[i,],
                                 nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])]) 
    wave1$brier_ideo_base[i] <- brier10(rep(10, 10),
                                   nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])])
    wave1$brier_ideo_mid[i] <- brier10(c(rep(20, 5),rep(0,5)),
                                       nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])])
    wave1$brier_ideo_party[i] <- brier10(nom_rep_base,
                                         nominate$nominate[(nominate$candidate_id == wave1$win_cand_id[i])])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_ideo[i] <- brier10(dem_ideo_2[i,],
                                   nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])]) 
    wave2$brier_ideo_base[i] <- brier10(rep(10, 10),
                                        nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])])
    wave2$brier_ideo_mid[i] <- brier10(c(rep(0, 5),rep(20,5)),
                                       nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])])
    wave2$brier_ideo_party[i] <- brier10(nom_dem_base,
                                         nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_ideo[i] <- brier10(rep_ideo_2[i,],
                                   nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])]) 
    wave2$brier_ideo_base[i] <- brier10(rep(10, 10),
                                        nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])])
    wave2$brier_ideo_mid[i] <- brier10(c(rep(20, 5),rep(0,5)),
                                       nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])])
    wave2$brier_ideo_party[i] <- brier10(nom_rep_base,
                                         nominate$nominate[(nominate$candidate_id == wave2$win_cand_id[i])])
  }
}

wave1$dem_expect_ideo <- ((dem_ideo_1/100) %*% 1:10) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_ideo <- ((dem_ideo_2/100) %*% 1:10)
wave1$rep_expect_ideo <- ((rep_ideo_1/100) %*% 1:10)
wave2$rep_expect_ideo <- ((rep_ideo_2/100) %*% 1:10)


# abortion (nrlc = 252)
dem_abort_1 <- getVectors(wave1$NRLC_dem_1, wave1$NRLC_dem_2, wave1$NRLC_dem_3,
                          wave1$NRLC_dem_4, wave1$NRLC_dem_5)

dem_abort_2 <- getVectors(wave2$NRLC_dem_1, wave2$NRLC_dem_2, wave2$NRLC_dem_3,
                          wave2$NRLC_dem_4, wave2$NRLC_dem_5)

rep_abort_1 <- getVectors(wave1$NRLC_rep_1, wave1$NRLC_rep_2, wave1$NRLC_rep_3,
                          wave1$NRLC_rep_4, wave1$NRLC_rep_5)

rep_abort_2 <- getVectors(wave2$NRLC_rep_1, wave2$NRLC_rep_2, wave2$NRLC_rep_3,
                          wave2$NRLC_rep_4, wave2$NRLC_rep_5)

wave1$brier_abort <- wave2$brier_abort <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_abort[i] <- brier(dem_abort_1[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "252"])
    wave1$brier_abort_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "252"])
    wave1$brier_abort_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "252"])
    wave1$brier_abort_party[i] <- brier(party_base["nrlc", 1:5, "Democrats"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "252"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_abort[i] <- brier(rep_abort_1[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "252"]) 
    wave1$brier_abort_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "252"])
    wave1$brier_abort_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "252"])
    wave1$brier_abort_party[i] <- brier(party_base["nrlc", 1:5, "Republicans"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "252"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_abort[i] <- brier(dem_abort_2[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "252"])
    wave2$brier_abort_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "252"])
    wave2$brier_abort_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "252"])
    wave2$brier_abort_party[i] <- brier(party_base["nrlc", 1:5, "Democrats"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "252"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_abort[i] <- brier(rep_abort_2[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "252"]) 
    wave2$brier_abort_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "252"])
    wave2$brier_abort_mid[i] <- brier(c(0,0, rep(100/3, 3)),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "252"])
    wave2$brier_abort_party[i] <- brier(party_base["nrlc", 1:5, "Republicans"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "252"])
  }
}

wave1$dem_expect_abort <- ((dem_abort_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_abort <- ((dem_abort_2/100) %*% 1:5)
wave1$rep_expect_abort <- ((rep_abort_1/100) %*% 1:5)
wave2$rep_expect_abort <- ((rep_abort_2/100) %*% 1:5)

# taxes (cfg=1734)
dem_tax_1 <- getVectors(wave1$CfG_dem_1, wave1$CfG_dem_2, wave1$CfG_dem_3,
                        wave1$CfG_dem_4, wave1$CfG_dem_11)

dem_tax_2 <- getVectors(wave2$CfG_dem_1, wave2$CfG_dem_2, wave2$CfG_dem_3,
                        wave2$CfG_dem_4, wave2$CfG_dem_11)

rep_tax_1 <- getVectors(wave1$CFG_rep_1, wave1$CFG_rep_2, wave1$CFG_rep_3,
                        wave1$CFG_rep_4, wave1$CFG_rep_11)

rep_tax_2 <- getVectors(wave2$CFG_rep_1, wave2$CFG_rep_2, wave2$CFG_rep_3,
                        wave2$CFG_rep_4, wave2$CFG_rep_11)

wave1$brier_tax <- wave2$brier_tax <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_tax[i] <- brier(dem_tax_1[i,],
                                vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                      & vote_smart$sig_id == "1734"])
    wave1$brier_tax_base[i] <- brier(rep(20, 5),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1734"])
    wave1$brier_tax_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1734"])
    wave1$brier_tax_party[i] <- brier(party_base["cfg", 1:5, "Democrats"] * 100,
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1734"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_tax[i] <- brier(rep_tax_1[i,],
                                vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                      & vote_smart$sig_id == "1734"]) 
    wave1$brier_tax_base[i] <- brier(rep(20, 5),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1734"])
    wave1$brier_tax_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                    vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                          & vote_smart$sig_id == "1734"])
    wave1$brier_tax_party[i] <- brier(party_base["cfg", 1:5, "Republicans"] * 100,
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1734"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_tax[i] <- brier(dem_tax_2[i,],
                                vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                      & vote_smart$sig_id == "1734"])
    wave2$brier_tax_base[i] <- brier(rep(20, 5),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1734"])
    wave2$brier_tax_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                    vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                          & vote_smart$sig_id == "1734"])
    wave2$brier_tax_party[i] <- brier(party_base["cfg", 1:5, "Democrats"] * 100,
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1734"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_tax[i] <- brier(rep_tax_2[i,],
                                vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                      & vote_smart$sig_id == "1734"]) 
    wave2$brier_tax_base[i] <- brier(rep(20, 5),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1734"])
    wave2$brier_tax_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                    vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                          & vote_smart$sig_id == "1734"])
    wave2$brier_tax_party[i] <- brier(party_base["cfg", 1:5, "Republicans"] * 100,
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1734"])
  }
}

wave1$dem_expect_tax <- ((dem_tax_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_tax <- ((dem_tax_2/100) %*% 1:5)
wave1$rep_expect_tax <- ((rep_tax_1/100) %*% 1:5)
wave2$rep_expect_tax <- ((rep_tax_2/100) %*% 1:5)

# civil rights (hrc=1256)
dem_civil_right_1 <- getVectors(wave1$HRC_dem_1, wave1$HRC_dem_2, wave1$HRC_dem_3,
                                wave1$HRC_dem_4, wave1$HRC_dem_5)

dem_civil_right_2 <- getVectors(wave2$HRC_dem_1, wave2$HRC_dem_2, wave2$HRC_dem_3,
                                wave2$HRC_dem_4, wave2$HRC_dem_5)

rep_civil_right_1 <- getVectors(wave1$HRC_rep_1, wave1$HRC_rep_2, wave1$HRC_rep_3,
                                wave1$HRC_rep_4, wave1$HRC_rep_5)

rep_civil_right_2 <- getVectors(wave2$HRC_rep_1, wave2$HRC_rep_2, wave2$HRC_rep_3,
                                wave2$HRC_rep_4, wave2$HRC_rep_5)

wave1$brier_civil_right <- wave2$brier_civil_right <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_civil_right[i] <- brier(dem_civil_right_1[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1256"])
    wave1$brier_civil_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "1256"])
    wave1$brier_civil_right_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "1256"])
    wave1$brier_civil_right_party[i] <- brier(party_base["hrc", 1:5, "Democrats"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "1256"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_civil_right[i] <- brier(rep_civil_right_1[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1256"]) 
    wave1$brier_civil_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "1256"])
    wave1$brier_civil_right_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "1256"])
    wave1$brier_civil_right_party[i] <- brier(party_base["hrc", 1:5, "Republicans"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "1256"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_civil_right[i] <- brier(dem_civil_right_2[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1256"])
    wave2$brier_civil_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "1256"])
    wave2$brier_civil_right_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "1256"])
    wave2$brier_civil_right_party[i] <- brier(party_base["hrc", 1:5, "Democrats"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "1256"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_civil_right[i] <- brier(rep_civil_right_2[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1256"]) 
    wave2$brier_civil_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "1256"])
    wave2$brier_civil_right_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "1256"])
    wave2$brier_civil_right_party[i] <- brier(party_base["hrc", 1:5, "Republicans"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "1256"])
  }
}

wave1$dem_expect_civil_right <- ((dem_civil_right_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_civil_right <- ((dem_civil_right_2/100) %*% 1:5)
wave1$rep_expect_civil_right <- ((rep_civil_right_1/100) %*% 1:5)
wave2$rep_expect_civil_right <- ((rep_civil_right_2/100) %*% 1:5)

# racial rights (naacp=893)
dem_racial_right_1 <- getVectors(wave1$NAACP_dem_1, wave1$NAACP_dem_2, wave1$NAACP_dem_3,
                                 wave1$NAACP_dem_4, wave1$NAACP_dem_5)

dem_racial_right_2 <- getVectors(wave2$NAACP_dem_1, wave2$NAACP_dem_2, wave2$NAACP_dem_3,
                                 wave2$NAACP_dem_4, wave2$NAACP_dem_5)

rep_racial_right_1 <- getVectors(wave1$NAACP_rep_1, wave1$NAACP_rep_2, wave1$NAACP_rep_3,
                                 wave1$NAACP_rep_4, wave1$NAACP_rep_5)

rep_racial_right_2 <- getVectors(wave2$NAACP_rep_1, wave2$NAACP_rep_2, wave2$NAACP_rep_3,
                                 wave2$NAACP_rep_4, wave2$NAACP_rep_5)

wave1$brier_racial_right <- wave2$brier_racial_right <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_racial_right[i] <- brier(dem_racial_right_1[i,],
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "893"])
    wave1$brier_racial_right_base[i] <- brier(rep(20, 5),
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "893"])
    wave1$brier_racial_right_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "893"])
    wave1$brier_racial_right_party[i] <- brier(party_base["naacp", 1:5, "Democrats"] * 100,
                                               vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                     & vote_smart$sig_id == "893"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_racial_right[i] <- brier(rep_racial_right_1[i,],
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "893"]) 
    wave1$brier_racial_right_base[i] <- brier(rep(20, 5),
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "893"])
    wave1$brier_racial_right_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "893"])
    wave1$brier_racial_right_party[i] <- brier(party_base["naacp", 1:5, "Republicans"] * 100,
                                               vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                     & vote_smart$sig_id == "893"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_racial_right[i] <- brier(dem_racial_right_2[i,],
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "893"])
    wave2$brier_racial_right_base[i] <- brier(rep(20, 5),
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "893"])
    wave2$brier_racial_right_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "893"])
    wave2$brier_racial_right_party[i] <- brier(party_base["naacp", 1:5, "Democrats"] * 100,
                                               vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                     & vote_smart$sig_id == "893"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_racial_right[i] <- brier(rep_racial_right_2[i,],
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "893"]) 
    wave2$brier_racial_right_base[i] <- brier(rep(20, 5),
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "893"])
    wave2$brier_racial_right_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "893"])
    wave2$brier_racial_right_party[i] <- brier(party_base["naacp", 1:5, "Republicans"] * 100,
                                               vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                     & vote_smart$sig_id == "893"])
  }
}

wave1$dem_expect_racial_right <- ((dem_racial_right_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_racial_right <- ((dem_racial_right_2/100) %*% 1:5)
wave1$rep_expect_racial_right <- ((rep_racial_right_1/100) %*% 1:5)
wave2$rep_expect_racial_right <- ((rep_racial_right_2/100) %*% 1:5)

# marijuana (norml=599)
dem_marijuana_1 <- getVectors(wave1$NORML_dem_1, wave1$NORML_dem_2, wave1$NORML_dem_3,
                              wave1$NORML_dem_4, wave1$NORML_dem_5)

dem_marijuana_2 <- getVectors(wave2$NORML_dem_1, wave2$NORML_dem_2, wave2$NORML_dem_3,
                              wave2$NORML_dem_4, wave2$NORML_dem_5)

rep_marijuana_1 <- getVectors(wave1$NORML_rep_1, wave1$NORML_rep_2, wave1$NORML_rep_3,
                              wave1$NORML_rep_4, wave1$NORML_rep_5)

rep_marijuana_2 <- getVectors(wave2$NORML_rep_1, wave2$NORML_rep_2, wave2$NORML_rep_3,
                              wave2$NORML_rep_4, wave2$NORML_rep_5)

wave1$brier_marijuana <- wave2$brier_marijuana <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_marijuana[i] <- brier(dem_marijuana_1[i,],
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "599"])
    wave1$brier_marijuana_base[i] <- brier(rep(20, 5),
                                           vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                 & vote_smart$sig_id == "599"])
    wave1$brier_marijuana_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "599"])
    wave1$brier_marijuana_party[i] <- brier(party_base["normal", 1:5, "Democrats"] * 100,
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "599"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_marijuana[i] <- brier(rep_marijuana_1[i,],
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "599"]) 
    wave1$brier_marijuana_base[i] <- brier(rep(20, 5),
                                           vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                 & vote_smart$sig_id == "599"])
    wave1$brier_marijuana_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "599"])
    wave1$brier_marijuana_party[i] <- brier(party_base["normal", 1:5, "Republicans"] * 100,
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "599"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_marijuana[i] <- brier(dem_marijuana_2[i,],
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "599"])
    wave2$brier_marijuana_base[i] <- brier(rep(20, 5),
                                           vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                 & vote_smart$sig_id == "599"])
    wave2$brier_marijuana_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "599"])
    wave2$brier_marijuana_party[i] <- brier(party_base["normal", 1:5, "Democrats"] * 100,
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "599"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_marijuana[i] <- brier(rep_marijuana_2[i,],
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "599"]) 
    wave2$brier_marijuana_base[i] <- brier(rep(20, 5),
                                           vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                 & vote_smart$sig_id == "599"])
    wave2$brier_marijuana_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "599"])
    wave2$brier_marijuana_party[i] <- brier(party_base["normal", 1:5, "Republicans"] * 100,
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "599"])
  }
}

wave1$dem_expect_marijuana <- ((dem_marijuana_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_marijuana <- ((dem_marijuana_2/100) %*% 1:5)
wave1$rep_expect_marijuana <- ((rep_marijuana_1/100) %*% 1:5)
wave2$rep_expect_marijuana <- ((rep_marijuana_2/100) %*% 1:5)

# religious rights (afa action=2622)
dem_relig_right_1 <- getVectors(wave1$AFA_dem_1, wave1$AFA_dem_2, wave1$AFA_dem_3,
                                wave1$AFA_dem_4, wave1$AFA_dem_5)

dem_relig_right_2 <- getVectors(wave2$AFA_dem_1, wave2$AFA_dem_2, wave2$AFA_dem_3,
                                wave2$AFA_dem_4, wave2$AFA_dem_5)

rep_relig_right_1 <- getVectors(wave1$AFA_rep_1, wave1$AFA_rep_2, wave1$AFA_rep_3,
                                wave1$AFA_rep_4, wave1$AFA_rep_5)

rep_relig_right_2 <- getVectors(wave2$AFA_rep_1, wave2$AFA_rep_2, wave2$AFA_rep_3,
                                wave2$AFA_rep_4, wave2$AFA_rep_5)

wave1$brier_relig_right <- wave2$brier_relig_right <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_relig_right[i] <- brier(dem_relig_right_1[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "2622"])
    wave1$brier_relig_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "2622"])
    wave1$brier_relig_right_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "2622"])
    wave1$brier_relig_right_party[i] <- brier(party_base["afa", 1:5, "Democrats"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "2622"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_relig_right[i] <- brier(rep_relig_right_1[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "2622"]) 
    wave1$brier_relig_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "2622"])
    wave1$brier_relig_right_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "2622"])
    wave1$brier_relig_right_party[i] <- brier(party_base["afa", 1:5, "Republicans"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "2622"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_relig_right[i] <- brier(dem_relig_right_2[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "2622"])
    wave2$brier_relig_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "2622"])
    wave2$brier_relig_right_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "2622"])
    wave2$brier_relig_right_party[i] <- brier(party_base["afa", 1:5, "Democrats"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "2622"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_relig_right[i] <- brier(rep_relig_right_2[i,],
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "2622"]) 
    wave2$brier_relig_right_base[i] <- brier(rep(20, 5),
                                             vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                   & vote_smart$sig_id == "2622"])
    wave2$brier_relig_right_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                            vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                  & vote_smart$sig_id == "2622"])
    wave2$brier_relig_right_party[i] <- brier(party_base["afa", 1:5, "Republicans"] * 100,
                                              vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                    & vote_smart$sig_id == "2622"])
  }
}

wave1$dem_expect_relig_right <- ((dem_relig_right_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_relig_right <- ((dem_relig_right_2/100) %*% 1:5)
wave1$rep_expect_relig_right <- ((rep_relig_right_1/100) %*% 1:5)
wave2$rep_expect_relig_right <- ((rep_relig_right_2/100) %*% 1:5)

# environment (lcv=1012)
dem_enviro_1 <- getVectors(wave1$LCV_dem_1, wave1$LCV_dem_2, wave1$LCV_dem_3,
                           wave1$LCV_dem_4, wave1$LCV_dem_5)

dem_enviro_2 <- getVectors(wave2$LCV_dem_1, wave2$LCV_dem_2, wave2$LCV_dem_3,
                           wave2$LCV_dem_4, wave2$LCV_dem_5)

rep_enviro_1 <- getVectors(wave1$LCV_rep_1, wave1$LCV_rep_2, wave1$LCV_rep_3,
                           wave1$LCV_rep_4, wave1$LCV_rep_5)

rep_enviro_2 <- getVectors(wave2$LCV_rep_1, wave2$LCV_rep_2, wave2$LCV_rep_3,
                           wave2$LCV_rep_4, wave2$LCV_rep_5)

wave1$brier_enviro <- wave2$brier_enviro <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_enviro[i] <- brier(dem_enviro_1[i,],
                                   vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                         & vote_smart$sig_id == "1012"])
    wave1$brier_enviro_base[i] <- brier(rep(20, 5),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1012"])
    wave1$brier_enviro_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1012"])
    wave1$brier_enviro_party[i] <- brier(party_base["lcv", 1:5, "Democrats"] * 100,
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1012"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_enviro[i] <- brier(rep_enviro_1[i,],
                                   vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                         & vote_smart$sig_id == "1012"]) 
    wave1$brier_enviro_base[i] <- brier(rep(20, 5),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1012"])
    wave1$brier_enviro_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1012"])
    wave1$brier_enviro_party[i] <- brier(party_base["lcv", 1:5, "Republicans"] * 100,
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1012"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_enviro[i] <- brier(dem_enviro_2[i,],
                                   vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                         & vote_smart$sig_id == "1012"])
    wave2$brier_enviro_base[i] <- brier(rep(20, 5),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1012"])
    wave2$brier_enviro_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1012"])
    wave2$brier_enviro_party[i] <- brier(party_base["lcv", 1:5, "Democrats"] * 100,
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1012"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_enviro[i] <- brier(rep_enviro_2[i,],
                                   vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                         & vote_smart$sig_id == "1012"]) 
    wave2$brier_enviro_base[i] <- brier(rep(20, 5),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1012"])
    wave2$brier_enviro_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1012"])
    wave2$brier_enviro_party[i] <- brier(party_base["lcv", 1:5, "Republicans"] * 100,
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1012"])
  }
}

wave1$dem_expect_enviro <- ((dem_enviro_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_enviro <- ((dem_enviro_2/100) %*% 1:5)
wave1$rep_expect_enviro <- ((rep_enviro_1/100) %*% 1:5)
wave2$rep_expect_enviro <- ((rep_enviro_2/100) %*% 1:5)

# guns (nra=1034)
dem_guns_1 <- getVectors(wave1$NRA_dem_1, wave1$NRA_dem_2, wave1$NRA_dem_3,
                         wave1$NRA_dem_4, wave1$NRA_dem_5)

dem_guns_2 <- getVectors(wave2$NRA_dem_1, wave2$NRA_dem_2, wave2$NRA_dem_3,
                         wave2$NRA_dem_4, wave2$NRA_dem_5)

rep_guns_1 <- getVectors(wave1$NRA_rep_1, wave1$NRA_rep_2, wave1$NRA_rep_3,
                         wave1$NRA_rep_4, wave1$NRA_rep_5)

rep_guns_2 <- getVectors(wave2$NRA_rep_1, wave2$NRA_rep_2, wave2$NRA_rep_3,
                         wave2$NRA_rep_4, wave2$NRA_rep_5)

wave1$brier_guns <- wave2$brier_guns <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_guns[i] <- brier(dem_guns_1[i,],
                                 vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                       & vote_smart$sig_id == "1034"])
    wave1$brier_guns_base[i] <- brier(rep(20, 5),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1034"])
    wave1$brier_guns_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1034"])
    wave1$brier_guns_party[i] <- brier(party_base["nra", 1:5, "Democrats"] * 100,
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1034"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_guns[i] <- brier(rep_guns_1[i,],
                                 vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                       & vote_smart$sig_id == "1034"]) 
    wave1$brier_guns_base[i] <- brier(rep(20, 5),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1034"])
    wave1$brier_guns_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1034"])
    wave1$brier_guns_party[i] <- brier(party_base["nra", 1:5, "Republicans"] * 100,
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1034"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_guns[i] <- brier(dem_guns_2[i,],
                                 vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                       & vote_smart$sig_id == "1034"])
    wave2$brier_guns_base[i] <- brier(rep(20, 5),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1034"])
    wave2$brier_guns_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1034"])
    wave2$brier_guns_party[i] <- brier(party_base["nra", 1:5, "Democrats"] * 100,
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1034"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_guns[i] <- brier(rep_guns_2[i,],
                                 vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                       & vote_smart$sig_id == "1034"]) 
    wave2$brier_guns_base[i] <- brier(rep(20, 5),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1034"])
    wave2$brier_guns_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                     vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                           & vote_smart$sig_id == "1034"])
    wave2$brier_guns_party[i] <- brier(party_base["nra", 1:5, "Republicans"] * 100,
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1034"])
  }
}

wave1$dem_expect_guns <- ((dem_guns_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_guns <- ((dem_guns_2/100) %*% 1:5)
wave1$rep_expect_guns <- ((rep_guns_1/100) %*% 1:5)
wave2$rep_expect_guns <- ((rep_guns_2/100) %*% 1:5)

# immigration (nusa=1985)
dem_immig_1 <- getVectors(wave1$NUSA_dem_1, wave1$NUSA_dem_2, wave1$NUSA_dem_3,
                          wave1$NUSA_dem_4, wave1$NUSA_dem_5)

dem_immig_2 <- getVectors(wave2$NUSA_dem_1, wave2$NUSA_dem_2, wave2$NUSA_dem_3,
                          wave2$NUSA_dem_4, wave2$NUSA_dem_5)

rep_immig_1 <- getVectors(wave1$NUSA_rep_1, wave1$NUSA_rep_2, wave1$NUSA_rep_3,
                          wave1$NUSA_rep_4, wave1$NUSA_rep_5)

rep_immig_2 <- getVectors(wave2$NUSA_rep_1, wave2$NUSA_rep_2, wave2$NUSA_rep_3,
                          wave2$NUSA_rep_4, wave2$NUSA_rep_5)

wave1$brier_immig <- wave2$brier_immig <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_immig[i] <- brier(dem_immig_1[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1985"])
    wave1$brier_immig_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1985"])
    wave1$brier_immig_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1985"])
    wave1$brier_immig_party[i] <- brier(party_base["nusa", 1:5, "Democrats"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1985"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_immig[i] <- brier(rep_immig_1[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1985"]) 
    wave1$brier_immig_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1985"])
    wave1$brier_immig_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1985"])
    wave1$brier_immig_party[i] <- brier(party_base["nusa", 1:5, "Republicans"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1985"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_immig[i] <- brier(dem_immig_2[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1985"])
    wave2$brier_immig_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1985"])
    wave2$brier_immig_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1985"])
    wave2$brier_immig_party[i] <- brier(party_base["nusa", 1:5, "Democrats"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1985"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_immig[i] <- brier(rep_immig_2[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1985"]) 
    wave2$brier_immig_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1985"])
    wave2$brier_immig_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1985"])
    wave2$brier_immig_party[i] <- brier(party_base["nusa", 1:5, "Republicans"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1985"])
  }
}

wave1$dem_expect_immig <- ((dem_immig_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_immig <- ((dem_immig_2/100) %*% 1:5)
wave1$rep_expect_immig <- ((rep_immig_1/100) %*% 1:5)
wave2$rep_expect_immig <- ((rep_immig_2/100) %*% 1:5)

# labor unions (afl-cio=1161)
dem_labor_1 <- getVectors(wave1$AFLCIO_dem_1, wave1$AFLCIO_dem_2, wave1$AFLCIO_dem_3,
                          wave1$AFLCIO_dem_4, wave1$AFLCIO_dem_5)

dem_labor_2 <- getVectors(wave2$AFLCIO_dem_1, wave2$AFLCIO_dem_2, wave2$AFLCIO_dem_3,
                          wave2$AFLCIO_dem_4, wave2$AFLCIO_dem_5)

rep_labor_1 <- getVectors(wave1$AFLCIO_rep_1, wave1$AFLCIO_rep_2, wave1$AFLCIO_rep_3,
                          wave1$AFLCIO_rep_4, wave1$AFLCIO_rep_5)

rep_labor_2 <- getVectors(wave2$AFLCIO_rep_1, wave2$AFLCIO_rep_2, wave2$AFLCIO_rep_3,
                          wave2$AFLCIO_rep_4, wave2$AFLCIO_rep_5)

wave1$brier_labor <- wave2$brier_labor <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_labor[i] <- brier(dem_labor_1[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1161"])
    wave1$brier_labor_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1161"])
    wave1$brier_labor_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1161"])
    wave1$brier_labor_party[i] <- brier(party_base["aflcio", 1:5, "Democrats"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1161"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_labor[i] <- brier(rep_labor_1[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1161"]) 
    wave1$brier_labor_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1161"])
    wave1$brier_labor_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1161"])
    wave1$brier_labor_party[i] <- brier(party_base["aflcio", 1:5, "Republicans"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1161"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_labor[i] <- brier(dem_labor_2[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1161"])
    wave2$brier_labor_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1161"])
    wave2$brier_labor_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1161"])
    wave2$brier_labor_party[i] <- brier(party_base["aflcio", 1:5, "Democrats"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1161"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_labor[i] <- brier(rep_labor_2[i,],
                                  vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                        & vote_smart$sig_id == "1161"]) 
    wave2$brier_labor_base[i] <- brier(rep(20, 5),
                                       vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                             & vote_smart$sig_id == "1161"])
    wave2$brier_labor_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                      vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                            & vote_smart$sig_id == "1161"])
    wave2$brier_labor_party[i] <- brier(party_base["aflcio", 1:5, "Republicans"] * 100,
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1161"])
  }
}

wave1$dem_expect_labor <- ((dem_labor_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_labor <- ((dem_labor_2/100) %*% 1:5)
wave1$rep_expect_labor <- ((rep_labor_1/100) %*% 1:5)
wave2$rep_expect_labor <- ((rep_labor_2/100) %*% 1:5)

# inequality (results=1744)
dem_inequal_1 <- getVectors(wave1$RESULTS_dem_1, wave1$RESULTS_dem_2, wave1$RESULTS_dem_3,
                            wave1$RESULTS_dem_4, wave1$RESULTS_dem_5)

dem_inequal_2 <- getVectors(wave2$RESULTS_dem_1, wave2$RESULTS_dem_2, wave2$RESULTS_dem_3,
                            wave2$RESULTS_dem_4, wave2$RESULTS_dem_5)

rep_inequal_1 <- getVectors(wave1$RESULTS_rep_1, wave1$RESULTS_rep_2, wave1$RESULTS_rep_3,
                            wave1$RESULTS_rep_4, wave1$RESULTS_rep_5)

rep_inequal_2 <- getVectors(wave2$RESULTS_rep_1, wave2$RESULTS_rep_2, wave2$RESULTS_rep_3,
                            wave2$RESULTS_rep_4, wave2$RESULTS_rep_5)

wave1$brier_inequal <- wave2$brier_inequal <- NA
for (i in 1:nrow(wave1)){
  if (wave1$win_cand_party[i] == "Democratic"){
    wave1$brier_inequal[i] <- brier(dem_inequal_1[i,],
                                    vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                          & vote_smart$sig_id == "1744"])
    wave1$brier_inequal_base[i] <- brier(rep(20, 5),
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1744"])
    wave1$brier_inequal_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1744"])
    wave1$brier_inequal_party[i] <- brier(party_base["results", 1:5, "Democrats"] * 100,
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "1744"])
  }else if (wave1$win_cand_party[i] == "Republican"){
    wave1$brier_inequal[i] <- brier(rep_inequal_1[i,],
                                    vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                          & vote_smart$sig_id == "1744"]) 
    wave1$brier_inequal_base[i] <- brier(rep(20, 5),
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1744"])
    wave1$brier_inequal_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1744"])
    wave1$brier_inequal_party[i] <- brier(party_base["results", 1:5, "Republicans"] * 100,
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave1$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "1744"])
  }
}
for (i in 1:nrow(wave2)){
  if (wave2$win_cand_party[i] == "Democratic"){
    wave2$brier_inequal[i] <- brier(dem_inequal_2[i,],
                                    vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                          & vote_smart$sig_id == "1744"])
    wave2$brier_inequal_base[i] <- brier(rep(20, 5),
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1744"])
    wave2$brier_inequal_mid[i] <- brier(c(0,0,rep(100/3, 3)),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1744"])
    wave2$brier_inequal_party[i] <- brier(party_base["results", 1:5, "Democrats"] * 100,
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "1744"])
  }else if (wave2$win_cand_party[i] == "Republican"){
    wave2$brier_inequal[i] <- brier(rep_inequal_2[i,],
                                    vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                          & vote_smart$sig_id == "1744"]) 
    wave2$brier_inequal_base[i] <- brier(rep(20, 5),
                                         vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                               & vote_smart$sig_id == "1744"])
    wave2$brier_inequal_mid[i] <- brier(c(rep(100/3, 3),0,0),
                                        vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                              & vote_smart$sig_id == "1744"])
    wave2$brier_inequal_party[i] <- brier(party_base["results", 1:5, "Republicans"] * 100,
                                          vote_smart$rating_avg[(vote_smart$candidate_id == wave2$win_cand_id[i]) 
                                                                & vote_smart$sig_id == "1744"])
  }
}

wave1$dem_expect_inequal <- ((dem_inequal_1/100) %*% 1:5) # W1 expected value of dem candidate for each respondent
wave2$dem_expect_inequal <- ((dem_inequal_2/100) %*% 1:5)
wave1$rep_expect_inequal <- ((rep_inequal_1/100) %*% 1:5)
wave2$rep_expect_inequal <- ((rep_inequal_2/100) %*% 1:5)


### boxplots###

orgs <- c("nominate","nrlc","cfg","hrc","naacp","normal","lcv","nusa","results","aflcio")
issues <- c("ideo","abort","tax","civil_right","racial_right","marijuana","enviro","immig","inequal","labor")

pdf("Figures/boxplots.pdf", height = 6, width = 10, family="serif", pointsize=12)
par(mar=c(3,4,2,1), mfrow=c(2, 5))
for (i in 1:length(issues)){
  boxplot(list(Wave_1 = eval(parse(text=paste0("wave1$brier_", issues[i]))),
               Wave_2 = eval(parse(text=paste0("wave2$brier_", issues[i])))
  ),
  ylim=c(0,2), boxwex = 0.5
  )
  abline(h=sapply(list(mean(eval(parse(text=paste0("wave1$brier_", issues[i], "_base"))), na.rm = T), 
                       mean(eval(parse(text=paste0("wave1$brier_", issues[i], "_mid"))), na.rm = T), 
                       mean(eval(parse(text=paste0("wave1$brier_", issues[i], "_party"))), na.rm = T)), 
                  median, na.rm=T),
         lty=1:3, col=c("blue","orange","red")
  )
  if(i==1){legend("topright", c("Equal probs","Naive party","Expert party"), lty=1:3, col=c("blue","orange","red"), bty="n")}
  title(main=toupper(orgs)[i])
}
dev.off()


## merge survey data with actual candidate data

# merge wave 1 with actual candidate data
wave1$candidate_id <- wave1$win_cand_id
groups <- c("NRLC","CfG","HRC","NAACP","NORML","LCV","NUSA","AFLCIO","RESULTS")
sig_ids <- c(252,1734,1256,893,599,1012,1985,1161,1744)
for (j in 1:length(groups)){
  wave1[,groups[j]] <- wave1[,paste0(groups[j], "_ss")] <- NA
  for (i in 1:nrow(wave1)){
    wave1[i,groups[j]] <- vote_smart$rating_avg[vote_smart$sig_id == sig_ids[j]
                                                & vote_smart$candidate_id == wave1$candidate_id[i]][1]
    wave1[i,paste0(groups[j], "_ss")] <- vote_smart_all$rating_avg[vote_smart_all$sig_id == sig_ids[j]
                                                & vote_smart_all$candidate_id == 
                                                  cand_data$samestate_id[cand_data$candidate_id == wave1$candidate_id[i]]][1]
  }
} 

# NOMINATE
wave1$NOMINATE <- wave1$NOMINATE_ss <- NA
for (i in 1:nrow(wave1)){
  wave1$NOMINATE[i] <- nominate$nominate[nominate$candidate_id == wave1$candidate_id[i]]
  wave1$NOMINATE_ss[i] <- nominate$samestate[nominate$candidate_id == wave1$candidate_id[i]]
}

# merge wave 2 with actual candidate data
wave2$candidate_id <- wave2$win_cand_id
groups <- c("NRLC","CfG","HRC","NAACP","NORML","LCV","NUSA","AFLCIO","RESULTS")
sig_ids <- c(252,1734,1256,893,599,1012,1985,1161,1744)
for (j in 1:length(groups)){
  wave2[,groups[j]] <- wave2[,paste0(groups[j], "_ss")]  <- NA
  for (i in 1:nrow(wave2)){
    wave2[i,groups[j]] <- vote_smart$rating_avg[vote_smart$sig_id == sig_ids[j]
                                                & vote_smart$candidate_id == wave2$candidate_id[i]][1]
    wave2[i,paste0(groups[j], "_ss")] <- vote_smart_all$rating_avg[vote_smart_all$sig_id == sig_ids[j]
                                                                   & vote_smart_all$candidate_id == 
                                                                     cand_data$samestate_id[cand_data$candidate_id == wave2$candidate_id[i]]][1]
  }
} 

# NOMINATE
wave2$NOMINATE <- wave2$NOMINATE_ss  <- NA
for (i in 1:nrow(wave2)){
  wave2$NOMINATE[i] <- nominate$nominate[nominate$candidate_id == wave2$candidate_id[i]]
  wave2$NOMINATE_ss[i] <- nominate$samestate[nominate$candidate_id == wave2$candidate_id[i]]
}


## expected values for respondent beliefs

# create expected rating variables for wave 1
wave1$expect_ideo <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_ideo, 
                            ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_ideo, NA))
wave1$expect_abort <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_abort, 
                             ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_abort, NA))
wave1$expect_tax <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_tax, 
                           ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_tax, NA))
wave1$expect_civil_right <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_civil_right, 
                                   ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_civil_right, NA))
wave1$expect_racial_right <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_racial_right, 
                                    ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_racial_right, NA))
wave1$expect_marijuana <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_marijuana, 
                                 ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_marijuana, NA))
wave1$expect_enviro <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_enviro, 
                              ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_enviro, NA))
wave1$expect_immig <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_immig, 
                             ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_immig, NA))
wave1$expect_labor <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_labor, 
                             ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_labor, NA))
wave1$expect_inequal <- ifelse(wave1$win_cand_party == "Democratic", wave1$dem_expect_inequal, 
                               ifelse(wave1$win_cand_party == "Republican", wave1$rep_expect_inequal, NA))

# create expected rating variables for wave 2
wave2$expect_ideo <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_ideo, 
                            ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_ideo, NA))
wave2$expect_abort <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_abort, 
                             ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_abort, NA))
wave2$expect_tax <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_tax, 
                           ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_tax, NA))
wave2$expect_civil_right <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_civil_right, 
                                   ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_civil_right, NA))
wave2$expect_racial_right <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_racial_right, 
                                    ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_racial_right, NA))
wave2$expect_marijuana <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_marijuana, 
                                 ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_marijuana, NA))
wave2$expect_enviro <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_enviro, 
                              ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_enviro, NA))
wave2$expect_immig <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_immig, 
                             ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_immig, NA))
wave2$expect_labor <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_labor, 
                             ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_labor, NA))
wave2$expect_inequal <- ifelse(wave2$win_cand_party == "Democratic", wave2$dem_expect_inequal, 
                               ifelse(wave2$win_cand_party == "Republican", wave2$rep_expect_inequal, NA))

# export wave 1 and 2 data
write.csv(wave1, "Data/Wave 1 Data with Beliefs.csv", row.names = F)
write.csv(wave2, "Data/Wave 2 Data with Beliefs.csv", row.names = F)


##### Descriptive figures #####

## summary figures for beliefs

# adjust NOMINATE scores to match issues
dem_nom_1 <- matrix(NA, nrow(dem_ideo_1), 5)
dem_nom_2 <- matrix(NA, nrow(dem_ideo_2), 5)
rep_nom_1 <- matrix(NA, nrow(rep_ideo_1), 5)
rep_nom_2 <- matrix(NA, nrow(rep_ideo_2), 5)

for (i in 1:5){
  dem_nom_1[,i] <- dem_ideo_1[,i + (i-1)] + dem_ideo_1[,i+i] 
  dem_nom_2[,i] <- dem_ideo_2[,i + (i-1)] + dem_ideo_2[,i+i] 
  rep_nom_1[,i] <- rep_ideo_1[,i + (i-1)] + rep_ideo_1[,i+i] 
  rep_nom_2[,i] <- rep_ideo_2[,i + (i-1)] + rep_ideo_2[,i+i] 
}

# list all belief vars
belief_vars <- list(dem_nom_1,dem_nom_2,rep_nom_1,rep_nom_2, 
                    dem_abort_1,dem_abort_2,rep_abort_1,rep_abort_2,
                    dem_tax_1,dem_tax_2,rep_tax_1,rep_tax_2,
                    dem_civil_right_1,dem_civil_right_2,rep_civil_right_1,rep_civil_right_2,
                    dem_racial_right_1,dem_racial_right_2,rep_racial_right_1,rep_racial_right_2,
                    dem_marijuana_1,dem_marijuana_2,rep_marijuana_1,rep_marijuana_2,
                    dem_relig_right_1,dem_relig_right_2,rep_relig_right_1,rep_relig_right_2,
                    dem_enviro_1,dem_enviro_2,rep_enviro_1,rep_enviro_2,
                    dem_guns_1,dem_guns_2,rep_guns_1,rep_guns_2,
                    dem_immig_1,dem_immig_2,rep_immig_1,rep_immig_2,
                    dem_labor_1,dem_labor_2,rep_labor_1,rep_labor_2,
                    dem_inequal_1,dem_inequal_2,rep_inequal_1,rep_inequal_2)

iss_labs <- c("Liberalism","Anti Abortion","Anti Taxes","Pro Civil Rights","Pro Racial Equality",
              "Pro Marijuana","Pro Religious Rights","Pro Environment","Pro Guns",
              "Pro Immigration","Pro Labor","Anti Inequality")
group_labs <- c("NOMINATE Scores","NRLC","Club for Growth","Human Rights Campaign",
                "NAACP","NORML","AFA Action","Conservation Voters",
                "NRA","Numbers USA","AFL-CIO","RESULTS")
groups <- c("NRLC","CfG","HRC","NAACP","NORML","LCV","NUSA","AFLCIO","RESULTS")


pdf(file="Figures/ProbSums.pdf", 
    height = 6, width = 8, family="serif", pointsize=12)
par(mfrow=c(3,4), mar=c(4,4,2,1))
for (i in 1:12){
  plot(colMeans(belief_vars[[i+3*(i-1)]], na.rm = T), type="l", col="blue", lwd=1,
       ylim=c(0,100), xlim=c(1,5), ylab="Average Probability", xlab="")
  lines(colMeans(belief_vars[[i+3*(i-1)+1]], na.rm = T), type="l", col="blue", lty=1,lwd=4)
  lines(colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T), type="l", col="red", lwd=1, lty=3)
  lines(colMeans(belief_vars[[i+3*(i-1)+3]], na.rm = T), type="l", col="red", lty=3, lwd=4)
  title(main=group_labs[i]) 
  title(xlab=iss_labs[i], line = 2)
  if (i == 2){
    legend("top", c("Wave 1 (D)","Wave 2 (D)","Wave 1 (R)", "Wave 2 (R)"), 
           lty=c(1,1,3,3), lwd=c(1,4,1,4), col=c("blue","blue","red","red"), bty="n", cex=1)}
}
dev.off()

# Calculation for Club for Growth (reported in text)
i = which(group_labs == "Club for Growth")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) - colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T)

# Calculation for League of Conservation Voters (reported in text)
i = which(group_labs == "Conservation Voters")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) - colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T)

# Calculation for AFL-CIO (reported in text)
i = which(group_labs == "AFL-CIO")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) - colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T)

# Calculation for National Right to Life Council (reported in text)
i = which(group_labs == "NRLC")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) - colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T)

# Calculation for Human Rights Campaign (reported in text)
i = which(group_labs == "Human Rights Campaign")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) - colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T)

# Calculation for RESULTS (reported in text)
i = which(group_labs == "RESULTS")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) - colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T)

# Calculation for NRA (reported in text)
i = which(group_labs == "NRA")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) - colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T)

# NRA by party in Wave 1
i = which(group_labs == "NRA")
colMeans(belief_vars[[i+3*(i-1)]], na.rm = T) # Dems
colMeans(belief_vars[[i+3*(i-1)+2]], na.rm = T) # Reps

# NRA by party in Wave 2
i = which(group_labs == "NRA")
colMeans(belief_vars[[i+3*(i-1)+1]], na.rm = T) # Dems
colMeans(belief_vars[[i+3*(i-1)+3]], na.rm = T) # Reps


## absolute distance of expected value from true value

# function to put true value on same scale as EV
EV <- function(x, type=5){
  if (type == 5){
    return(sapply(x, function(y) findInterval(y, c(0,20,40,60,80,101))))
  }else if (type == 10){
    return(sapply(x, function(y) findInterval(y, c(0,10,20,30,40,50,60,70,80,90,101))))
  }
}


## Wave 1

# NOMINATE
wave1$dist_ideo <- abs(wave1$expect_ideo - EV(wave1$NOMINATE, type=10))
wave1$dist_ideo_base <- abs(rep(5.5, nrow(wave1)) - EV(101-wave1$NOMINATE, type=10))
wave1$dist_ideo_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 3, 8) - EV(101-wave1$NOMINATE, type=10))
wave1$dist_ideo_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                               party_base["nominate", , "Democrats"] %*% 1:10, 
                               party_base["nominate", , "Republicans"] %*% 1:10) - EV(101-wave1$NOMINATE, type=10))

# NRLC
wave1$dist_abort <- abs(wave1$expect_abort - EV(wave1$NRLC, type=5))
wave1$dist_abort_base <- abs(rep(3, nrow(wave1)) - EV(wave1$NRLC, type=5))
wave1$dist_abort_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 2, 4) - EV(wave1$NRLC, type=5))
wave1$dist_abort_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                     party_base["nrlc", 1:5, "Democrats"] %*% 1:5, 
                                     party_base["nrlc", 1:5, "Republicans"] %*% 1:5) - EV(wave1$NRLC, type=5))

# CfG
wave1$dist_tax <- abs(wave1$expect_tax - EV(wave1$CfG, type=5))
wave1$dist_tax_base <- abs(rep(3, nrow(wave1)) - EV(wave1$CfG, type=5))
wave1$dist_tax_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 2, 4) - EV(wave1$CfG, type=5))
wave1$dist_tax_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                   party_base["cfg", 1:5, "Democrats"] %*% 1:5, 
                                   party_base["cfg", 1:5, "Republicans"] %*% 1:5) - EV(wave1$CfG, type=5))

# HRC
wave1$dist_civil_right <- abs(wave1$expect_civil_right - EV(wave1$HRC, type=5))
wave1$dist_civil_right_base <- abs(rep(3, nrow(wave1)) - EV(wave1$HRC, type=5))
wave1$dist_civil_right_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 4, 2) - EV(wave1$HRC, type=5))
wave1$dist_civil_right_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                           party_base["hrc", 1:5, "Democrats"] %*% 1:5, 
                                           party_base["hrc", 1:5, "Republicans"] %*% 1:5) - EV(wave1$HRC, type=5))

# NAACP
wave1$dist_racial_right <- abs(wave1$expect_racial_right - EV(wave1$NAACP, type=5))
wave1$dist_racial_right_base <- abs(rep(3, nrow(wave1)) - EV(wave1$NAACP, type=5))
wave1$dist_racial_right_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 4, 2) - EV(wave1$NAACP, type=5))
wave1$dist_racial_right_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                            party_base["naacp", 1:5, "Democrats"] %*% 1:5, 
                                            party_base["naacp", 1:5, "Republicans"] %*% 1:5) - EV(wave1$NAACP, type=5))

# NORML
wave1$dist_marijuana <- abs(wave1$expect_marijuana - EV(wave1$NORML, type=5))
wave1$dist_marijuana_base <- abs(rep(3, nrow(wave1)) - EV(wave1$NORML, type=5))
wave1$dist_marijuana_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 4, 2) - EV(wave1$NORML, type=5))
wave1$dist_marijuana_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                         party_base["normal", 1:5, "Democrats"] %*% 1:5, 
                                         party_base["normal", 1:5, "Republicans"] %*% 1:5) - EV(wave1$NORML, type=5))

# LCV
wave1$dist_enviro <- abs(wave1$expect_enviro - EV(wave1$LCV, type=5))
wave1$dist_enviro_base <- abs(rep(3, nrow(wave1)) - EV(wave1$LCV, type=5))
wave1$dist_enviro_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 4, 2) - EV(wave1$LCV, type=5))
wave1$dist_enviro_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                      party_base["lcv", 1:5, "Democrats"] %*% 1:5, 
                                      party_base["lcv", 1:5, "Republicans"] %*% 1:5) - EV(wave1$LCV, type=5))

# NUSA
wave1$dist_immig <- abs(wave1$expect_immig - EV(wave1$NUSA, type=5))
wave1$dist_immig_base <- abs(rep(3, nrow(wave1)) - EV(wave1$NUSA, type=5))
wave1$dist_immig_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 2, 4) - EV(wave1$NUSA, type=5))
wave1$dist_immig_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                     party_base["nusa", 1:5, "Democrats"] %*% 1:5, 
                                     party_base["nusa", 1:5, "Republicans"] %*% 1:5) - EV(wave1$NUSA, type=5))

# AFLCIO
wave1$dist_labor <- abs(wave1$expect_labor - EV(wave1$AFLCIO, type=5))
wave1$dist_labor_base <- abs(rep(3, nrow(wave1)) - EV(wave1$AFLCIO, type=5))
wave1$dist_labor_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 4, 2) - EV(wave1$AFLCIO, type=5))
wave1$dist_labor_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                     party_base["aflcio", 1:5, "Democrats"] %*% 1:5, 
                                     party_base["aflcio", 1:5, "Republicans"] %*% 1:5) - EV(wave1$AFLCIO, type=5))

# RESULTS
wave1$dist_inequal <- abs(wave1$expect_inequal - EV(wave1$RESULTS, type=5))
wave1$dist_inequal_base <- abs(rep(3, nrow(wave1)) - EV(wave1$RESULTS, type=5))
wave1$dist_inequal_mid <- abs(ifelse(wave1$win_cand_party == "Democratic", 4, 2) - EV(wave1$RESULTS, type=5))
wave1$dist_inequal_party <- abs(ifelse(wave1$win_cand_party == "Democratic", 
                                       party_base["results", 1:5, "Democrats"] %*% 1:5, 
                                       party_base["results", 1:5, "Republicans"] %*% 1:5) - EV(wave1$RESULTS, type=5))

## Wave 2

# NOMINATE
wave2$dist_ideo <- abs(wave2$expect_ideo - EV(wave2$NOMINATE, type=10))
wave2$dist_ideo_base <- abs(rep(5.5, nrow(wave2)) - EV(101-wave2$NOMINATE, type=10))
wave2$dist_ideo_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 3, 8) - EV(101-wave2$NOMINATE, type=10))
wave2$dist_ideo_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                    party_base["nominate", , "Democrats"] %*% 1:10, 
                                    party_base["nominate", , "Republicans"] %*% 1:10) - EV(101-wave2$NOMINATE, type=10))

# NRLC
wave2$dist_abort <- abs(wave2$expect_abort - EV(wave2$NRLC, type=5))
wave2$dist_abort_base <- abs(rep(3, nrow(wave2)) - EV(wave2$NRLC, type=5))
wave2$dist_abort_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 2, 4) - EV(wave2$NRLC, type=5))
wave2$dist_abort_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                     party_base["nrlc", 1:5, "Democrats"] %*% 1:5, 
                                     party_base["nrlc", 1:5, "Republicans"] %*% 1:5) - EV(wave2$NRLC, type=5))

# CfG
wave2$dist_tax <- abs(wave2$expect_tax - EV(wave2$CfG, type=5))
wave2$dist_tax_base <- abs(rep(3, nrow(wave2)) - EV(wave2$CfG, type=5))
wave2$dist_tax_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 2, 4) - EV(wave2$CfG, type=5))
wave2$dist_tax_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                   party_base["cfg", 1:5, "Democrats"] %*% 1:5, 
                                   party_base["cfg", 1:5, "Republicans"] %*% 1:5) - EV(wave2$CfG, type=5))

# HRC
wave2$dist_civil_right <- abs(wave2$expect_civil_right - EV(wave2$HRC, type=5))
wave2$dist_civil_right_base <- abs(rep(3, nrow(wave2)) - EV(wave2$HRC, type=5))
wave2$dist_civil_right_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 4, 2) - EV(wave2$HRC, type=5))
wave2$dist_civil_right_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                           party_base["hrc", 1:5, "Democrats"] %*% 1:5, 
                                           party_base["hrc", 1:5, "Republicans"] %*% 1:5) - EV(wave2$HRC, type=5))

# NAACP
wave2$dist_racial_right <- abs(wave2$expect_racial_right - EV(wave2$NAACP, type=5))
wave2$dist_racial_right_base <- abs(rep(3, nrow(wave2)) - EV(wave2$NAACP, type=5))
wave2$dist_racial_right_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 4, 2) - EV(wave2$NAACP, type=5))
wave2$dist_racial_right_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                            party_base["naacp", 1:5, "Democrats"] %*% 1:5, 
                                            party_base["naacp", 1:5, "Republicans"] %*% 1:5) - EV(wave2$NAACP, type=5))

# NORML
wave2$dist_marijuana <- abs(wave2$expect_marijuana - EV(wave2$NORML, type=5))
wave2$dist_marijuana_base <- abs(rep(3, nrow(wave2)) - EV(wave2$NORML, type=5))
wave2$dist_marijuana_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 4, 2) - EV(wave2$NORML, type=5))
wave2$dist_marijuana_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                         party_base["normal", 1:5, "Democrats"] %*% 1:5, 
                                         party_base["normal", 1:5, "Republicans"] %*% 1:5) - EV(wave2$NORML, type=5))

# LCV
wave2$dist_enviro <- abs(wave2$expect_enviro - EV(wave2$LCV, type=5))
wave2$dist_enviro_base <- abs(rep(3, nrow(wave2)) - EV(wave2$LCV, type=5))
wave2$dist_enviro_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 4, 2) - EV(wave2$LCV, type=5))
wave2$dist_enviro_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                      party_base["lcv", 1:5, "Democrats"] %*% 1:5, 
                                      party_base["lcv", 1:5, "Republicans"] %*% 1:5) - EV(wave2$LCV, type=5))

# NUSA
wave2$dist_immig <- abs(wave2$expect_immig - EV(wave2$NUSA, type=5))
wave2$dist_immig_base <- abs(rep(3, nrow(wave2)) - EV(wave2$NUSA, type=5))
wave2$dist_immig_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 2, 4) - EV(wave2$NUSA, type=5))
wave2$dist_immig_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                     party_base["nusa", 1:5, "Democrats"] %*% 1:5, 
                                     party_base["nusa", 1:5, "Republicans"] %*% 1:5) - EV(wave2$NUSA, type=5))

# AFLCIO
wave2$dist_labor <- abs(wave2$expect_labor - EV(wave2$AFLCIO, type=5))
wave2$dist_labor_base <- abs(rep(3, nrow(wave2)) - EV(wave2$AFLCIO, type=5))
wave2$dist_labor_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 4, 2) - EV(wave2$AFLCIO, type=5))
wave2$dist_labor_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                     party_base["aflcio", 1:5, "Democrats"] %*% 1:5, 
                                     party_base["aflcio", 1:5, "Republicans"] %*% 1:5) - EV(wave2$AFLCIO, type=5))

# RESULTS
wave2$dist_inequal <- abs(wave2$expect_inequal - EV(wave2$RESULTS, type=5))
wave2$dist_inequal_base <- abs(rep(3, nrow(wave2)) - EV(wave2$RESULTS, type=5))
wave2$dist_inequal_mid <- abs(ifelse(wave2$win_cand_party == "Democratic", 4, 2) - EV(wave2$RESULTS, type=5))
wave2$dist_inequal_party <- abs(ifelse(wave2$win_cand_party == "Democratic", 
                                       party_base["results", 1:5, "Democrats"] %*% 1:5, 
                                       party_base["results", 1:5, "Republicans"] %*% 1:5) - EV(wave2$RESULTS, type=5))


# boxplot
orgs <- c("nominate","nrlc","cfg","hrc","naacp","normal","lcv","nusa","results","aflcio")
issues <- c("ideo","abort","tax","civil_right","racial_right","marijuana","enviro","immig","inequal","labor")

pdf("Figures/boxplots_distance.pdf", height = 6, width = 10, family="serif", pointsize=12)
par(mar=c(3,4,2,1), mfrow=c(2, 5))
for (i in 1:length(issues)){
  boxplot(list(Wave_1 = eval(parse(text=paste0("wave1$dist_", issues[i]))),
               Wave_2 = eval(parse(text=paste0("wave2$dist_", issues[i])))
  ),
  ylim=c(0, 4 + c(7.5,rep(0,9))[i]), boxwex = 0.5
  )
  abline(h=sapply(list(mean(eval(parse(text=paste0("wave1$dist_", issues[i], "_base"))), na.rm = T), 
                       mean(eval(parse(text=paste0("wave1$dist_", issues[i], "_mid"))), na.rm = T), 
                       mean(eval(parse(text=paste0("wave1$dist_", issues[i], "_party"))), na.rm = T)), 
                  median, na.rm=T),
         lty=1:3, col=c("blue","orange","red")
  )
  if(i==1){legend("topright", c("Equal probs","Naive party","Expert party"), lty=1:3, col=c("blue","orange","red"), bty="n")}
  title(main=toupper(orgs)[i])
}
dev.off()


## bivariate relationship of reality to beliefs (figure 2) [RESULTS IS NOW MISSING]

# correlations wave 1
cor(wave1$expect_ideo, wave1$NOMINATE, use="pairwise.complete")
cor(wave1$expect_abort, wave1$NRLC, use="pairwise.complete")
cor(wave1$expect_tax, wave1$CfG, use="pairwise.complete")
cor(wave1$expect_civil_right, wave1$HRC, use="pairwise.complete")
cor(wave1$expect_racial_right, wave1$NAACP, use="pairwise.complete")
cor(wave1$expect_marijuana, wave1$NORML, use="pairwise.complete")
cor(wave1$expect_enviro, wave1$LCV, use="pairwise.complete")
cor(wave1$expect_immig, wave1$NUSA, use="pairwise.complete")
cor(wave1$expect_labor, wave1$AFLCIO, use="pairwise.complete")
cor(wave1$expect_inequal, wave1$RESULTS, use="pairwise.complete")

# correlations wave 2
cor(wave2$expect_ideo, wave2$NOMINATE, use="pairwise.complete")
cor(wave2$expect_abort, wave2$NRLC, use="pairwise.complete")
cor(wave2$expect_tax, wave2$CfG, use="pairwise.complete")
cor(wave2$expect_civil_right, wave2$HRC, use="pairwise.complete")
cor(wave2$expect_racial_right, wave2$NAACP, use="pairwise.complete")
cor(wave2$expect_marijuana, wave2$NORML, use="pairwise.complete")
cor(wave2$expect_enviro, wave2$LCV, use="pairwise.complete")
cor(wave2$expect_immig, wave2$NUSA, use="pairwise.complete")
cor(wave2$expect_labor, wave2$AFLCIO, use="pairwise.complete")
cor(wave2$expect_inequal, wave2$RESULTS, use="pairwise.complete")


## Linear specification (for paper)
coef_table <- array(NA, c(10,3,2))
m <- replicate(10, vector("list", 2), simplify = F)

pdf(file="Figures/AccuracyAll.pdf", 
    height = 4, width = 9, family="serif", pointsize=12)

par(mfrow=c(2,5), mar=c(3,3,2,1), oma=c(2,2,0,0))

plot(wave1$NOMINATE, wave1$expect_ideo,
     xlab="", ylab="", col="grey80", ylim=c(1,10))
points(wave2$NOMINATE, wave2$expect_ideo, col="grey60", pch=19)
m[[1]][[1]] <- lm(expect_ideo ~ NOMINATE, data = wave1)
m[[1]][[2]] <- lm(expect_ideo ~ NOMINATE, data = wave2)
lines(seq(0,100,1), predict(m[[1]][[1]], newdata = data.frame(NOMINATE = seq(0,100,1))), lwd=2, lty=2)
lines(seq(0,100,1), predict(m[[1]][[2]], newdata = data.frame(NOMINATE = seq(0,100,1))), lwd=2)
title(main="NOMINATE")
mtext("Respondent Beliefs", side = 2, line = 0, outer = T)
mtext("Actual Candidate Ratings", side = 1, line = 0, outer = T)

plot(wave1$NRLC, wave1$expect_abort,
     xlab="", ylab="", col="grey80")
points(wave2$NRLC, wave2$expect_abort, col="grey60", pch=19)
m[[2]][[1]] <- lm(expect_abort ~ NRLC, data = wave1)
m[[2]][[2]] <- lm(expect_abort ~ NRLC, data = wave2)
lines(c(0,100), predict(m[[2]][[1]], newdata = data.frame(NRLC = c(0,100))), lwd=2, lty=2)
lines(c(0,100), predict(m[[2]][[2]], newdata = data.frame(NRLC = c(0,100))), lwd=2)
title(main="NRLC")
legend("top", c("Wave 1","Wave2"), pch=c(1,19), lty=c(2,1), col=c("grey80","grey60"), bty="n", cex=1.2)

DVs <- c("expect_tax","expect_civil_right","expect_racial_right","expect_marijuana",
         "expect_enviro","expect_immig","expect_labor","expect_inequal")
for (i in 1:8){
  plot(wave1[,groups[i+1]], wave1[,DVs[i]],
       xlab="", ylab="", col="grey80", xlim=c(0,100))
  points(wave2[,groups[i+1]], wave2[,DVs[i]], col="grey60", pch=19)
  m[[i+2]][[1]] <- lm(as.formula(paste(DVs[i],"~",groups[i+1])), data = wave1)
  m[[i+2]][[2]] <- lm(as.formula(paste(DVs[i],"~",groups[i+1])), data = wave2)
  new_data <- data.frame(x = seq(min(wave1[,groups[i+1]], na.rm = T),
                                 max(wave1[,groups[i+1]], na.rm = T),
                                 1))
  colnames(new_data) <- groups[i+1]
  lines(seq(min(wave1[,groups[i+1]], na.rm = T),
            max(wave1[,groups[i+1]], na.rm = T),
            1), 
        predict(m[[i+2]][[1]], newdata = new_data), lwd=2, lty=2)
  lines(seq(min(wave1[,groups[i+1]], na.rm = T),
            max(wave1[,groups[i+1]], na.rm = T),
            1), 
        predict(m[[i+2]][[2]], newdata = new_data), lwd=2)
  title(main=group_labs[c(3:6,8,10:12)][i])
}

dev.off()


# coefficient tables
for (i in 1:10){
  coef_table[i,,1] <- cbind(coef(m[[i]][[1]])[2], confint(m[[i]][[1]])[2,1],confint(m[[i]][[1]])[2,2])
  coef_table[i,,2] <- cbind(coef(m[[i]][[2]])[2], confint(m[[i]][[2]])[2,1],confint(m[[i]][[2]])[2,2])
}
rownames(coef_table) <- group_labs[c(1:6,8,10:12)]
colnames(coef_table) <- c("Beta","LowCI","HighCI")
write.csv(100*coef_table[,,1], "Tables/Fig3_coefs_all_W1.csv", row.names = T)
write.csv(100*coef_table[,,2], "Tables/Fig3_coefs_all_W2.csv", row.names = T)


## Same-state/same-party analysis for appendix

ss_table <- array(NA, c(20,3,2))

m11 <- lm(expect_ideo ~ NOMINATE, data = wave1)
m12 <- lm(expect_ideo ~ NOMINATE, data = wave2)
m21 <- lm(expect_ideo ~ NOMINATE + NOMINATE_ss, data = wave1)
m22 <- lm(expect_ideo ~ NOMINATE + NOMINATE_ss, data = wave2)

ss_table[1, , 1] <- c(coef(m11)[2], confint(m11)[2,])
ss_table[1, , 2] <- c(coef(m12)[2], confint(m12)[2,])
ss_table[2, , 1] <- c(coef(m21)[2], confint(m21)[2,])
ss_table[2, , 2] <- c(coef(m22)[2], confint(m22)[2,])


DVs_ss <- c("expect_abort","expect_tax","expect_civil_right","expect_racial_right","expect_marijuana",
         "expect_enviro","expect_immig","expect_labor","expect_inequal")
for (i in 1:(length(groups))){
  m11 <- lm(as.formula(paste(DVs_ss[i],"~",groups[i])), data = wave1)
  m12 <- lm(as.formula(paste(DVs_ss[i],"~",groups[i])), data = wave2)
  m21 <- lm(as.formula(paste(DVs_ss[i],"~",groups[i], "+", paste0(groups[i], "_ss"))), data = wave1)
  m22 <- lm(as.formula(paste(DVs_ss[i],"~",groups[i], "+", paste0(groups[i], "_ss"))), data = wave2)
  
  ss_table[1 + 2*i, , 1] <- c(coef(m11)[2], confint(m11)[2,])
  ss_table[1 + 2*i, , 2] <- c(coef(m12)[2], confint(m12)[2,])
  ss_table[2 + 2*i, , 1] <- c(coef(m21)[2], confint(m21)[2,])
  ss_table[2 + 2*i, , 2] <- c(coef(m22)[2], confint(m22)[2,])
}

# cors of focal and same-state senators
group_cors <- c()
group_cors[1] <- cor(wave1$NOMINATE, wave1$NOMINATE_ss, use="complete.obs")
for (i in 1:length(groups)){
  group_cors <- append(group_cors, cor(wave1[, groups[i]], wave1[, paste0(groups[i], "_ss")], use="complete.obs"))
}
group_cors


# figure for SS
groups_ss <- groups
groups_ss[1] <- "NRLC*"

pdf(file="Figures/SameState.pdf", 
    height = 6, width = 8, family="serif", pointsize=12)

par(mar=c(5,6,1,1))

plot(ss_table[,1,1], seq(0.75,10.25,0.5), pch=c(19,1, 19,19, rep(c(19,1),8)), col=c("black","black","white","white",rep(c("black","black"),8)),
     xlim=c(-.04,0.1),
     xlab="Effect of actual ratings on beliefs", ylab="", axes=F)
axis(1, at=seq(-.04,0.1,0.02))
axis(2, at=1:10, c("NOMINATE",groups_ss), las=2)
segments(ss_table[,2,1], seq(0.75,10.25,0.5),
         ss_table[,3,1], seq(0.75,10.25,0.5), col=c("black","black","white","white",rep(c("black","black"),8)))
legend("right", c("Original estimates","Controlling for same-state Senator"), pch=c(19,1), bty="n")
abline(h=seq(1.5, 9.5, 1), v=0, lty=3)
text(rep(-0.04, 10), 1:10, sprintf("%.2f", round(group_cors, 3)))

dev.off()


## Quadratic specification (for appendix)
pdf(file="Figures/Figure 2_Quad.pdf", 
    height = 4, width = 10, family="serif", pointsize=11)

par(mfrow=c(2,5), mar=c(3,3,2,1), oma=c(2,2,0,0))

plot(wave1$NOMINATE, wave1$expect_ideo,
     xlab="", ylab="", col="grey80", ylim=c(1,10))
points(wave2$NOMINATE, wave2$expect_ideo, col="grey60", pch=19)
lines(seq(0,100,1), predict(lm(expect_ideo ~ NOMINATE + I(NOMINATE^2), data = wave1), 
                            newdata = data.frame(NOMINATE = seq(0,100,1))), lwd=2, lty=2)
lines(seq(0,100,1), predict(lm(expect_ideo ~ NOMINATE + I(NOMINATE^2), data = wave2), 
                            newdata = data.frame(NOMINATE = seq(0,100,1))), lwd=2)
title(main="NOMINATE")
mtext("Respondent Beliefs", side = 2, line = 0, outer = T)
mtext("Actual Candidate Ratings", side = 1, line = 0, outer = T)

plot(wave1$NRLC, wave1$expect_abort,
     xlab="", ylab="", col="grey80")
points(wave2$NRLC, wave2$expect_abort, col="grey60", pch=19)
lines(c(0,100), predict(lm(expect_abort ~ NRLC + I(NRLC^2), data = wave1), 
                        newdata = data.frame(NRLC = c(0,100))), lwd=2, lty=2)
lines(c(0,100), predict(lm(expect_abort ~ NRLC + I(NRLC^2), data = wave2), 
                        newdata = data.frame(NRLC = c(0,100))), lwd=2)
title(main="NRLC")
legend("top", c("Wave 1","Wave2"), pch=c(1,19), lty=c(2,1), col=c("grey80","grey60"), bty="n")

DVs <- c("expect_tax","expect_civil_right","expect_racial_right","expect_marijuana",
         "expect_enviro","expect_immig","expect_labor","expect_inequal")
for (i in 1:8){
  plot(wave1[,groups[i+1]], wave1[,DVs[i]],
       xlab="", ylab="", col="grey80", xlim=c(0,100))
  points(wave2[,groups[i+1]], wave2[,DVs[i]], col="grey60", pch=19)
  m1 <- lm(as.formula(paste(DVs[i],"~",groups[i+1],"+",paste("I(",groups[i+1],"^2)"))), data = wave1)
  m2 <- lm(as.formula(paste(DVs[i],"~",groups[i+1],"+",paste("I(",groups[i+1],"^2)"))), data = wave2)
  new_data <- data.frame(x = seq(min(wave1[,groups[i+1]], na.rm = T),
                                 max(wave1[,groups[i+1]], na.rm = T),
                                 1))
  colnames(new_data) <- groups[i+1]
  lines(seq(min(wave1[,groups[i+1]], na.rm = T),
            max(wave1[,groups[i+1]], na.rm = T),
            1), 
        predict(m1, newdata = new_data), lwd=2, lty=2)
  lines(seq(min(wave1[,groups[i+1]], na.rm = T),
            max(wave1[,groups[i+1]], na.rm = T),
            1), 
        predict(m2, newdata = new_data), lwd=2)
  title(main=group_labs[c(3:6,8,10:12)][i])
}

dev.off()


## bivariate relationship of reality to beliefs within democrats & republicans (figure 3)

# correlations wave 1
cor(wave1$expect_ideo[wave1$win_cand_party=="Democratic"], wave1$NOMINATE[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_abort[wave1$win_cand_party=="Democratic"], wave1$NRLC[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_tax[wave1$win_cand_party=="Democratic"], wave1$CfG[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_civil_right[wave1$win_cand_party=="Democratic"], wave1$HRC[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_racial_right[wave1$win_cand_party=="Democratic"], wave1$NAACP[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_marijuana[wave1$win_cand_party=="Democratic"], wave1$NORML[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_enviro[wave1$win_cand_party=="Democratic"], wave1$LCV[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_immig[wave1$win_cand_party=="Democratic"], wave1$NUSA[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_labor[wave1$win_cand_party=="Democratic"], wave1$AFLCIO[wave1$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave1$expect_inequal[wave1$win_cand_party=="Democratic"], wave1$RESULTS[wave1$win_cand_party=="Democratic"], use="pairwise.complete")

cor(wave1$expect_ideo[wave1$win_cand_party=="Republican"], wave1$NOMINATE[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_abort[wave1$win_cand_party=="Republican"], wave1$NRLC[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_tax[wave1$win_cand_party=="Republican"], wave1$CfG[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_civil_right[wave1$win_cand_party=="Republican"], wave1$HRC[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_racial_right[wave1$win_cand_party=="Republican"], wave1$NAACP[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_marijuana[wave1$win_cand_party=="Republican"], wave1$NORML[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_enviro[wave1$win_cand_party=="Republican"], wave1$LCV[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_immig[wave1$win_cand_party=="Republican"], wave1$NUSA[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_labor[wave1$win_cand_party=="Republican"], wave1$AFLCIO[wave1$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave1$expect_inequal[wave1$win_cand_party=="Republican"], wave1$RESULTS[wave1$win_cand_party=="Republican"], use="pairwise.complete")

# correlations wave 2
cor(wave2$expect_ideo[wave2$win_cand_party=="Democratic"], wave2$NOMINATE[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_abort[wave2$win_cand_party=="Democratic"], wave2$NRLC[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_tax[wave2$win_cand_party=="Democratic"], wave2$CfG[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_civil_right[wave2$win_cand_party=="Democratic"], wave2$HRC[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_racial_right[wave2$win_cand_party=="Democratic"], wave2$NAACP[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_marijuana[wave2$win_cand_party=="Democratic"], wave2$NORML[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_enviro[wave2$win_cand_party=="Democratic"], wave2$LCV[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_immig[wave2$win_cand_party=="Democratic"], wave2$NUSA[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_labor[wave2$win_cand_party=="Democratic"], wave2$AFLCIO[wave2$win_cand_party=="Democratic"], use="pairwise.complete")
cor(wave2$expect_inequal[wave2$win_cand_party=="Democratic"], wave2$RESULTS[wave2$win_cand_party=="Democratic"], use="pairwise.complete")

cor(wave2$expect_ideo[wave2$win_cand_party=="Republican"], wave2$NOMINATE[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_abort[wave2$win_cand_party=="Republican"], wave2$NRLC[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_tax[wave2$win_cand_party=="Republican"], wave2$CfG[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_civil_right[wave2$win_cand_party=="Republican"], wave2$HRC[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_racial_right[wave2$win_cand_party=="Republican"], wave2$NAACP[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_marijuana[wave2$win_cand_party=="Republican"], wave2$NORML[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_enviro[wave2$win_cand_party=="Republican"], wave2$LCV[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_immig[wave2$win_cand_party=="Republican"], wave2$NUSA[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_labor[wave2$win_cand_party=="Republican"], wave2$AFLCIO[wave2$win_cand_party=="Republican"], use="pairwise.complete")
cor(wave2$expect_inequal[wave2$win_cand_party=="Republican"], wave2$RESULTS[wave2$win_cand_party=="Republican"], use="pairwise.complete")


# Linear specification (for paper)
coef_table_D <- array(NA, c(10,3,2))
coef_table_R <- array(NA, c(10,3,2))
mD <- replicate(10, vector("list", 2), simplify = F)
mR <- replicate(10, vector("list", 2), simplify = F)

pdf(file="Figures/AccParty.pdf", 
    height = 4, width = 9, family="serif", pointsize=12)

par(mfrow=c(2,5), mar=c(3,3,2,1), oma=c(2,2,0,0))

plot(wave1$NOMINATE[wave1$win_cand_party=="Democratic"], wave1$expect_ideo[wave1$win_cand_party=="Democratic"],
     xlab="", ylab="", col=rgb(0,0,1,0.1, maxColorValue = 1), ylim=c(1,10), xlim=c(0,100))
points(wave2$NOMINATE[wave2$win_cand_party=="Democratic"], wave2$expect_ideo[wave2$win_cand_party=="Democratic"], 
       col=rgb(0,0,1,0.1, maxColorValue = 1), pch=19)
points(wave1$NOMINATE[wave1$win_cand_party=="Republican"], wave1$expect_ideo[wave1$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=0)
points(wave2$NOMINATE[wave2$win_cand_party=="Republican"], wave2$expect_ideo[wave2$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=15)
mD[[1]][[1]] <- lm(expect_ideo ~ NOMINATE, data = subset(wave1, win_cand_party=="Democratic"))
mD[[1]][[2]] <- lm(expect_ideo ~ NOMINATE, data = subset(wave2, win_cand_party=="Democratic"))
mR[[1]][[1]] <- lm(expect_ideo ~ NOMINATE, data = subset(wave1, win_cand_party=="Republican"))
mR[[1]][[2]] <- lm(expect_ideo ~ NOMINATE, data = subset(wave2, win_cand_party=="Republican"))
lines(seq(50,100,1), predict(mD[[1]][[1]], newdata = data.frame(NOMINATE = seq(50,100,1))), lwd=1, col="blue")
lines(seq(50,100,1), predict(mD[[1]][[2]], newdata = data.frame(NOMINATE = seq(50,100,1))), lwd=4, col="blue")
lines(seq(0,50,1), predict(mR[[1]][[1]],newdata = data.frame(NOMINATE = seq(0,50,1))), lwd=1, lty=2, col="red")
lines(seq(0,50,1), predict(mR[[1]][[2]],newdata = data.frame(NOMINATE = seq(0,50,1))), lwd=4, lty=2, col="red")
title(main="NOMINATE")

mtext("Respondent Beliefs", side = 2, line = 0, outer = T)
mtext("Actual Candidate Ratings", side = 1, line = 0, outer = T)

plot(wave1$NRLC[wave1$win_cand_party=="Democratic"], wave1$expect_abort[wave1$win_cand_party=="Democratic"],
     xlab="", ylab="", col=rgb(0,0,1,0.1, maxColorValue = 1))
points(wave2$NRLC[wave2$win_cand_party=="Democratic"], wave2$expect_abort[wave2$win_cand_party=="Democratic"], 
       col=rgb(0,0,1,0.1, maxColorValue = 1), pch=19)
points(wave1$NRLC[wave1$win_cand_party=="Republican"], wave1$expect_abort[wave1$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=0)
points(wave2$NRLC[wave2$win_cand_party=="Republican"], wave2$expect_abort[wave2$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=15)
mD[[2]][[1]] <- lm(expect_abort ~ NRLC, data = subset(wave1, win_cand_party=="Democratic"))
mD[[2]][[2]] <- lm(expect_abort ~ NRLC, data = subset(wave2, win_cand_party=="Democratic"))
lines(c(0,100), predict(mD[[2]][[1]], newdata = data.frame(NRLC = c(0,100))), lwd=4, col="blue")
lines(c(0,100), predict(mD[[2]][[2]], newdata = data.frame(NRLC = c(0,100))), lwd=1, col="blue")
points(100, mean(wave1$expect_abort[wave1$win_cand_party=="Republican"], na.rm = T), pch=0, cex=2, col="red")
points(100, mean(wave2$expect_abort[wave2$win_cand_party=="Republican"], na.rm = T), pch=15, cex=2, col="red")
title(main="NRLC")
legend("top", c("Wave 1 (D)","Wave 2 (D)","Wave 1 (R)", "Wave 2 (R)"), 
       lty=c(1,1,3,3), lwd=c(1,4,1,4), pch=c(1,19,0,15), col=c("blue","blue","red","red"), bty="n", cex=1.1)

DVs <- c("expect_tax","expect_civil_right","expect_racial_right","expect_marijuana",
         "expect_enviro","expect_immig","expect_labor","expect_inequal")
for (i in c(1:8)){
  plot(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], wave1[,DVs[i]][wave1$win_cand_party=="Democratic"],
       xlab="Actual Candidate Rating", ylab="Respondent's expected rating", col=rgb(0,0,1,0.1, maxColorValue = 1), xlim=c(0,100))
  points(wave2[,groups[i+1]][wave2$win_cand_party=="Democratic"], wave2[,DVs[i]][wave2$win_cand_party=="Democratic"], 
         col=rgb(0,0,1,0.1, maxColorValue = 1), pch=19)
  points(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], wave1[,DVs[i]][wave1$win_cand_party=="Republican"], 
         col=rgb(1,0,0,0.1, maxColorValue = 1), pch=0)
  points(wave2[,groups[i+1]][wave2$win_cand_party=="Republican"], wave2[,DVs[i]][wave2$win_cand_party=="Republican"], 
         col=rgb(1,0,0,0.1, maxColorValue = 1), pch=15)
  mD[[i+2]][[1]] <- lm(as.formula(paste(DVs[i],"~",groups[i+1])), data = subset(wave1, win_cand_party=="Democratic"))
  mD[[i+2]][[2]] <- lm(as.formula(paste(DVs[i],"~",groups[i+1])), data = subset(wave2, win_cand_party=="Democratic"))
  mR[[i+2]][[1]] <- lm(as.formula(paste(DVs[i],"~",groups[i+1])), data = subset(wave1, win_cand_party=="Republican"))
  mR[[i+2]][[2]] <- lm(as.formula(paste(DVs[i],"~",groups[i+1])), data = subset(wave2, win_cand_party=="Republican"))
  new_data1 <- data.frame(x = seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
                                  max(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
                                  1))
  new_data2 <- data.frame(x = seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
                                  max(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
                                  1))
  colnames(new_data1) <- colnames(new_data2) <- groups[i+1]
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            1), 
        predict(mD[[i+2]][[1]], newdata = new_data1), lwd=1, col="blue")
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            1), 
        predict(mD[[i+2]][[2]], newdata = new_data1), lwd=4, col="blue")
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            1), 
        predict(mR[[i+2]][[1]], newdata = new_data2), lwd=1, lty=2, col="red")
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            1), 
        predict(mR[[i+2]][[2]], newdata = new_data2), lwd=4, lty=2, col="red")
  title(main=group_labs[c(3:6,8,10:12)][i])
}

dev.off()


# coefficient tables
for (i in 1:10){
  coef_table_D[i,,1] <- cbind(coef(mD[[i]][[1]])[2], confint(mD[[i]][[1]])[2,1],confint(mD[[i]][[1]])[2,2])
  coef_table_D[i,,2] <- cbind(coef(mD[[i]][[2]])[2], confint(mD[[i]][[2]])[2,1],confint(mD[[i]][[2]])[2,2])
  if (i != 2){
    coef_table_R[i,,1] <- cbind(coef(mR[[i]][[1]])[2], confint(mR[[i]][[1]])[2,1],confint(mR[[i]][[1]])[2,2])
    coef_table_R[i,,2] <- cbind(coef(mR[[i]][[2]])[2], confint(mR[[i]][[2]])[2,1],confint(mR[[i]][[2]])[2,2]) 
  }
}
rownames(coef_table_D) <- group_labs[c(1:6,8,10:12)]
colnames(coef_table_D) <- c("Beta","LowCI","HighCI")
write.csv(10*coef_table_D[,,1], "Tables/Fig3_coefs_Dems_W1.csv", row.names = T)
write.csv(10*coef_table_D[,,2], "Tables/Fig3_coefs_Dems_W2.csv", row.names = T)

rownames(coef_table_R) <- group_labs[c(1:6,8,10:12)]
colnames(coef_table_R) <- c("Beta","LowCI","HighCI")
write.csv(10*coef_table_R[,,1], "Tables/Fig3_coefs_Reps_W1.csv", row.names = T)
write.csv(10*coef_table_R[,,2], "Tables/Fig3_coefs_Reps_W2.csv", row.names = T)

# calculation for Republican candidates LCV and NUSA (report in text, p 20)
10*coef_table_R[,,1]


# Quadratic specification (for appendix)
pdf(file="Figures/Figure 3_Quad.pdf", 
    height = 4, width = 10, family="serif", pointsize=11)

par(mfrow=c(2,5), mar=c(3,3,2,1), oma=c(2,2,0,0))

plot(wave1$NOMINATE[wave1$win_cand_party=="Democratic"], wave1$expect_ideo[wave1$win_cand_party=="Democratic"],
     xlab="", ylab="", col=rgb(0,0,1,0.1, maxColorValue = 1), ylim=c(1,10), xlim=c(0,100))
points(wave2$NOMINATE[wave2$win_cand_party=="Democratic"], wave2$expect_ideo[wave2$win_cand_party=="Democratic"], 
       col=rgb(0,0,1,0.1, maxColorValue = 1), pch=19)
points(wave1$NOMINATE[wave1$win_cand_party=="Republican"], wave1$expect_ideo[wave1$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=0)
points(wave2$NOMINATE[wave2$win_cand_party=="Republican"], wave2$expect_ideo[wave2$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=15)
lines(seq(50,100,1), predict(lm(expect_ideo ~ NOMINATE + I(NOMINATE^2), data = subset(wave1, win_cand_party=="Democratic")), 
                            newdata = data.frame(NOMINATE = seq(50,100,1))), lwd=1, col="blue")
lines(seq(50,100,1), predict(lm(expect_ideo ~ NOMINATE + I(NOMINATE^2), data = subset(wave2, win_cand_party=="Democratic")), 
                            newdata = data.frame(NOMINATE = seq(50,100,1))), lwd=4, col="blue")
lines(seq(0,50,1), predict(lm(expect_ideo ~ NOMINATE + I(NOMINATE^2), data = subset(wave1, win_cand_party=="Republican")), 
                            newdata = data.frame(NOMINATE = seq(0,50,1))), lwd=1, lty=2, col="red")
lines(seq(0,50,1), predict(lm(expect_ideo ~ NOMINATE + I(NOMINATE^2), data = subset(wave2, win_cand_party=="Republican")), 
                            newdata = data.frame(NOMINATE = seq(0,50,1))), lwd=4, lty=2, col="red")
title(main="NOMINATE")

mtext("Respondent Beliefs", side = 2, line = 0, outer = T)
mtext("Actual Candidate Ratings", side = 1, line = 0, outer = T)

plot(wave1$NRLC[wave1$win_cand_party=="Democratic"], wave1$expect_abort[wave1$win_cand_party=="Democratic"],
     xlab="", ylab="", col=rgb(0,0,1,0.1, maxColorValue = 1))
points(wave2$NRLC[wave2$win_cand_party=="Democratic"], wave2$expect_abort[wave2$win_cand_party=="Democratic"], 
       col=rgb(0,0,1,0.1, maxColorValue = 1), pch=19)
points(wave1$NRLC[wave1$win_cand_party=="Republican"], wave1$expect_abort[wave1$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=0)
points(wave2$NRLC[wave2$win_cand_party=="Republican"], wave2$expect_abort[wave2$win_cand_party=="Republican"], 
       col=rgb(1,0,0,0.1, maxColorValue = 1), pch=15)
lines(c(0,100), predict(lm(expect_abort ~ NRLC + I(NRLC^2), data = subset(wave1, win_cand_party=="Democratic")), 
                        newdata = data.frame(NRLC = c(0,100))), lwd=4, col="blue")
lines(c(0,100), predict(lm(expect_abort ~ NRLC + I(NRLC^2), data = subset(wave2, win_cand_party=="Democratic")), 
                        newdata = data.frame(NRLC = c(0,100))), lwd=1, col="blue")
points(100, mean(wave1$expect_abort[wave1$win_cand_party=="Republican"], na.rm = T), pch=0, cex=2, col="red")
points(100, mean(wave2$expect_abort[wave2$win_cand_party=="Republican"], na.rm = T), pch=15, cex=2, col="red")
title(main="NRLC")
legend("top", c("Wave 1 (D)","Wave 2 (D)","Wave 1 (R)", "Wave 2 (R)"), 
       lty=c(1,1,3,3), lwd=c(1,4,1,4), pch=c(1,19,0,15), col=c("blue","blue","red","red"), bty="n")

DVs <- c("expect_tax","expect_civil_right","expect_racial_right","expect_marijuana",
         "expect_enviro","expect_immig","expect_labor","expect_inequal")
for (i in c(1:8)){
  plot(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], wave1[,DVs[i]][wave1$win_cand_party=="Democratic"],
       xlab="Actual Candidate Rating", ylab="Respondent's expected rating", col=rgb(0,0,1,0.1, maxColorValue = 1), xlim=c(0,100))
  points(wave2[,groups[i+1]][wave2$win_cand_party=="Democratic"], wave2[,DVs[i]][wave2$win_cand_party=="Democratic"], 
         col=rgb(0,0,1,0.1, maxColorValue = 1), pch=19)
  points(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], wave1[,DVs[i]][wave1$win_cand_party=="Republican"], 
         col=rgb(1,0,0,0.1, maxColorValue = 1), pch=0)
  points(wave2[,groups[i+1]][wave2$win_cand_party=="Republican"], wave2[,DVs[i]][wave2$win_cand_party=="Republican"], 
         col=rgb(1,0,0,0.1, maxColorValue = 1), pch=15)
  m1 <- lm(as.formula(paste(DVs[i],"~",groups[i+1],"+",paste("I(",groups[i+1],"^2)"))), data = subset(wave1, win_cand_party=="Democratic"))
  m2 <- lm(as.formula(paste(DVs[i],"~",groups[i+1],"+",paste("I(",groups[i+1],"^2)"))), data = subset(wave2, win_cand_party=="Democratic"))
  m3 <- lm(as.formula(paste(DVs[i],"~",groups[i+1],"+",paste("I(",groups[i+1],"^2)"))), data = subset(wave1, win_cand_party=="Republican"))
  m4 <- lm(as.formula(paste(DVs[i],"~",groups[i+1],"+",paste("I(",groups[i+1],"^2)"))), data = subset(wave2, win_cand_party=="Republican"))
  new_data1 <- data.frame(x = seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
                                 max(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
                                 1))
  new_data2 <- data.frame(x = seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
                                  max(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
                                  1))
  colnames(new_data1) <- colnames(new_data2) <- groups[i+1]
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            1), 
        predict(m1, newdata = new_data1), lwd=1, col="blue")
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Democratic"], na.rm = T),
            1), 
        predict(m2, newdata = new_data1), lwd=4, col="blue")
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            1), 
        predict(m3, newdata = new_data2), lwd=1, lty=2, col="red")
  lines(seq(min(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            max(wave1[,groups[i+1]][wave1$win_cand_party=="Republican"], na.rm = T),
            1), 
        predict(m4, newdata = new_data2), lwd=4, lty=2, col="red")
  title(main=group_labs[c(3:6,8,10:12)][i])
}

dev.off()


##### Accuracy Analyses #####

# clear environment
rm(list=ls())

# load data
wave1 <- read.csv("Data/Wave 1 Data with Beliefs.csv", stringsAsFactors = F)
wave2 <- read.csv("Data/Wave 2 Data with Beliefs.csv", stringsAsFactors = F)


### predicting accuracy

# wave 1 likelihood of taking extreme positions in general 
wave1$iss_extreme01 <- rowMeans(abs(wave1[,c("iss_hrc01","iss_nrlc01","iss_afa01","iss_cfg01",
                                  "iss_naacp01","iss_afa01","iss_lcv01","iss_aflcio01",
                                  "iss_norml01","iss_nra01","iss_nusa01","iss_ideo01")] - .5), na.rm = T) / 0.50
summary(wave1$iss_extreme01)
hist(wave1$iss_extreme01)

# wave 2 likelihood of taking extreme positions in general 
wave2$iss_extreme01 <- rowMeans(abs(wave2[,c("iss_hrc01","iss_nrlc01","iss_afa01","iss_cfg01",
                                             "iss_naacp01","iss_afa01","iss_lcv01","iss_aflcio01",
                                             "iss_norml01","iss_nra01","iss_nusa01","iss_ideo01")] - .5), na.rm = T) / 0.50
summary(wave2$iss_extreme01)
hist(wave2$iss_extreme01)

# reshape to long format
wave1$imp_ideo01 <- NA # stand-in for ideo importance, which does not exist
wave1_long <- reshape(wave1, 
                      varying = list(
                        c("brier_inequal","brier_labor","brier_immig","brier_guns",
                          "brier_enviro","brier_relig_right","brier_marijuana",
                          "brier_racial_right","brier_civil_right","brier_tax",
                          "brier_abort","brier_ideo"),
                        c("imp_welfare01","imp_labor01","imp_immig01","imp_guns01",
                          "imp_enviro01","imp_relig01","imp_drugs01",
                          "imp_race01","imp_sex01","imp_tax01","imp_abort01","imp_ideo01"),
                        c("iss_results01","iss_aflcio01","iss_nusa01","iss_nra01",
                          "iss_lcv01","iss_afa01","iss_norml01","iss_naacp01","iss_hrc01","iss_cfg01",
                          "iss_nrlc01","iss_ideo01")
                      ), 
                      v.names = c("brier","import","issue"),
                      direction = "long", 
                      times = c("inequal","labor","immig","guns","enviro","relig_right",
                                "marijuana","racial_right","civil_right","tax","abort","ideo")
                      )

wave2$imp_ideo01 <- NA # stand-in for ideo importance, which does not exist
wave2_long <- reshape(wave2, 
                      varying = list(
                        c("brier_inequal","brier_labor","brier_immig","brier_guns",
                          "brier_enviro","brier_relig_right","brier_marijuana",
                          "brier_racial_right","brier_civil_right","brier_tax",
                          "brier_abort","brier_ideo"),
                        c("imp_welfare01","imp_labor01","imp_immig01","imp_guns01",
                          "imp_enviro01","imp_relig01","imp_drugs01",
                          "imp_race01","imp_sex01","imp_tax01","imp_abort01","imp_ideo01"),
                        c("iss_results01","iss_aflcio01","iss_nusa01","iss_nra01",
                          "iss_lcv01","iss_afa01","iss_norml01","iss_naacp01","iss_hrc01","iss_cfg01",
                          "iss_nrlc01","iss_ideo01")
                      ), 
                      v.names = c("brier","import","issue"),
                      direction = "long", 
                      times = c("inequal","labor","immig","guns","enviro","relig_right",
                                "marijuana","racial_right","civil_right","tax","abort","ideo")
)


## estimate models with random intercept for survey respondents

library(lme4)

comb <- list()
# wave 1
comb[[1]] <- lmer((2 - brier) ~ age01 + male + black + hisp + educ01 + income01 + unemp + union + engage01 + pid_str01 
               + import + iss_extreme01 + I(abs(issue-.5)/.5) + factor(time) + (1 | id), data=wave1_long)

# wave 2
comb[[2]] <- lmer((2 - brier) ~ age01 + male + black + hisp + educ01 + income01 + unemp + union + engage01 + pid_str01 
               + import + iss_extreme01 + I(abs(issue-.5)/.5) + factor(time) + (1 | id), data=wave2_long)

# merge wave1_long and wave2_long
merged_waves_long <- merge(wave1_long, wave2_long, by="MID")

# # wave 1 estimates with only people who also have wave 2
# comb[[1]] <- lmer((2 - brier.x) ~ age01.x + male.x + black.x + hisp.x + educ01.x 
#                   + income01.x + unemp.x + union.x + engage01.x + pid_str01.x 
#                   + import.x + iss_extreme01.x + I(abs(issue.x-.5)/.5) + factor(time.x) + (1 | MID), 
#                   data=subset(merged_waves_long, !is.na(brier.y)))

# change in brier scores
comb[[3]] <- lmer((brier.x - brier.y) ~ I(2 - brier.x) + age01.x + male.x + black.x + hisp.x + educ01.x 
               + income01.x + unemp.x + union.x + engage01.x + pid_str01.x 
               + import.x + iss_extreme01.x + I(abs(issue.x-.5)/.5) + factor(time.x) + (1 | MID), data=merged_waves_long)

# post-est
comb_est <- array(NA, c(13, 3, 3)) # of coefs, # of models, 3 quantities (coef, 95% CIs)
for (i in 1:2){
  comb_est[1:13,i,1] <- fixef(comb[[i]])[2:14]
  comb_est[1:13,i,2] <- confint(comb[[i]])[4:16,1]
  comb_est[1:13,i,3] <- confint(comb[[i]])[4:16,2]
}
comb_est[1:13,3,1] <- fixef(comb[[3]])[3:15]
comb_est[1:13,3,2] <- confint(comb[[3]])[5:17,1]
comb_est[1:13,3,3] <- confint(comb[[3]])[5:17,2]


labs <- c("Age","Male","Black","Hispanic","Education","Income","Unemployed","In-union",
          "Political engagement","PID strength","Specific issue importance",
          "Specific issue extremity","Avg issue extremity")
titles <- c("NUSA","NRLC","Club for Growth","NAACP","Human Rights Campaign",
            "RESULTS","AFL-CIO","Conservation Voters","NORML","NOMINATE")

pdf(file="Figures/AccReg.pdf", height = 4, width = 10, family="serif", pointsize=12)

par(mfrow=c(1,3), mar=c(3,10,2,1))
for (i in 1:3){
  plot(comb_est[,i,1], 1:13,
       ylab = "", xlab = "", ylim = c(1,14), xlim = c(-0.5,0.5), 
       axes = F, pch = 19)
  axis(1, at=seq(-1,1,0.5))
  axis(2, at=1:13, labels = c(labs[1:11],labs[13],labs[12]), las=2)
  segments(comb_est[,i,2], 1:13,
           comb_est[,i,3], 1:13)
  abline(v=0, lty=3)
  title(main=c("Wave 1","Wave 2","Change, W2-W1")[i])
}

dev.off()

# does incumbency matter for learning?

merged_waves_long$incumb <- ifelse(merged_waves_long$state_name.x %in% c("California","Connecticut","Hawaii",
                                                                         "Maryland","Massachusetts","Michigan",
                                                                         "Minnesota","Mississippi","Montana",
                                                                         "Nebraska","New Jersey","New Mexico",
                                                                         "New York","Ohio","Pennsylvania","Texas",
                                                                         "Vermont","Virginia","Washington",
                                                                         "West Virginia","Wisconsin","Wyoming"), 1, 0)
table(merged_waves_long$incumb) / sum(table(merged_waves_long$incumb))

# previously estimated model
m_incumb_1 <- lmer((brier.x - brier.y) ~ I(2 - brier.x) + age01.x + male.x + black.x + hisp.x + educ01.x 
                  + income01.x + unemp.x + union.x + engage01.x + pid_str01.x 
                  + import.x + iss_extreme01.x + I(abs(issue.x-.5)/.5) + incumb + factor(time.x)
                  + (1 | MID), data=merged_waves_long)
summary(m_incumb_1)

# removing 1st wave scores as control
m_incumb_2 <- lmer((brier.x - brier.y) ~ age01.x + male.x + black.x + hisp.x + educ01.x 
                   + income01.x + unemp.x + union.x + engage01.x + pid_str01.x 
                   + import.x + iss_extreme01.x + I(abs(issue.x-.5)/.5) + incumb + factor(time.x)
                   + (1 | MID), data=merged_waves_long)
summary(m_incumb_2)


